/*
 * callbacks.c
 * lessonplan
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */
 
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#include <gtk/gtk.h>
#include <sys/stat.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "lpweekly.h"
#include "lpsql.h"
#include "lpclass.h"
#include <xhtmlite/xhtmlite_module/xhtmlcallbacks.h>
#include <xhtmlite/xhtmlite_module/xhtmlmenu.h>

static GtkWidget *lp_dialog_filechooser;
static GtkFileFilter *filefilter_selected;


static void
lp_set_currentdate (GtkWidget * lp_window_main)
{
	printf ("date:\n");
	// get current date and set screen date to this weeks monday
	
	GDate *mydate = g_date_new ();
	g_date_set_time (mydate, time(NULL));

//	GtkWidget *lp_main_label_date = lookup_widget (lp_window_main, "lp_main_label_date");
//	gchar mydate_string[101];
//	g_date_strftime (mydate_string, 100, "%Y/%m/%d\0", mydate);
//	printf ("current date:%s\n", mydate_string);
//	gtk_label_set_text (GTK_LABEL (lp_main_label_date), mydate_string);
//
//	lp_date_get_first_of_week(mydate, lp_options_get_weekday_first(-1));	// to get difference between monday and current day_of_week
//	g_date_strftime (mydate_string, 100, "%Y/%m/%d\0", mydate);
//	printf ("current date:%s\n", mydate_string);
//	gtk_label_set_text (GTK_LABEL (lp_main_label_date), mydate_string);
//	g_object_set_data (G_OBJECT(lp_main_label_date), "date", mydate);
	
	lp_weekly_setup (lp_window_main, mydate);
}


static void
lp_on_back_week_activate (GtkWidget * widget)
{
	GtkWidget *lp_main_label_date = lookup_widget (widget, "lp_main_label_date");
	GDate *date = g_object_get_data (G_OBJECT(lp_main_label_date), "date");
	g_date_subtract_days (date, 7);
	lp_weekly_setup (widget, date);
}


static void
lp_on_forward_week_activate (GtkWidget * widget)
{
	GtkWidget *lp_main_label_date = lookup_widget (widget, "lp_main_label_date");
	GDate *date = g_object_get_data (G_OBJECT(lp_main_label_date), "date");
	g_date_add_days (date, 7);
	lp_weekly_setup (widget, date);
}


void
lp_callbacks_setup_window_main(GtkWidget * lp_window_main)
{
  	//add the textview toolbars
	GtkWidget *vbox1 = lookup_widget(lp_window_main, "vbox1");
	GtkWidget *toolbar = xhtmlite_create_default_toolbar_edit(lp_window_main);
    gtk_box_pack_start (GTK_BOX (vbox1), toolbar, FALSE, TRUE, 0);
   	gtk_box_reorder_child (GTK_BOX (vbox1),toolbar,2);
	gtk_widget_show_all(toolbar);
	toolbar = xhtmlite_create_default_toolbar_font(lp_window_main);
	GtkWidget *toolitem_combobox_fontsize_pt = lookup_widget(lp_window_main, "toolitem_combobox_fontsize_pt");
    gtk_box_pack_start (GTK_BOX (vbox1), toolbar, FALSE, TRUE, 0);
	gtk_box_reorder_child (GTK_BOX (vbox1),toolbar,3);
	gtk_widget_show_all(toolbar);
	//Hide menus and menuitems not implemented yet
	gtk_widget_hide(toolitem_combobox_fontsize_pt);
	GtkWidget *widget = lookup_widget(lp_window_main, "menu_view");
	gtk_widget_hide(widget);
	widget = lookup_widget(lp_window_main, "menu_search");
	gtk_widget_hide(widget);
	widget = lookup_widget(lp_window_main, "lp_menuitem_print_preview");
	gtk_widget_hide(widget);
	widget = lookup_widget(lp_window_main, "lp_menuitem_print");
	gtk_widget_hide(widget);	
	/*add custom icons*/
	widget = lookup_widget(lp_window_main, "menuitem_edit_classes1");
	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(widget), gtk_image_new_from_stock ("apple", GTK_ICON_SIZE_MENU));
	widget = lookup_widget(lp_window_main, "menuitem_lesson_plans1");
	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(widget), gtk_image_new_from_stock ("lessonplan", GTK_ICON_SIZE_MENU));
	widget = lookup_widget(lp_window_main, "menuitem_standards_list1");
	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(widget), gtk_image_new_from_stock ("gavel", GTK_ICON_SIZE_MENU));
	widget = lookup_widget(lp_window_main, "choose_date1");
	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(widget), gtk_image_new_from_stock ("weeklyplan", GTK_ICON_SIZE_MENU));
	widget = lookup_widget(lp_window_main, "about1");
	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM(widget), gtk_image_new_from_stock ("help", GTK_ICON_SIZE_MENU));
	widget = lookup_widget(lp_window_main, "lp_window_main_image_weekly");
	gtk_image_set_from_stock (GTK_IMAGE(widget), "weeklyplan", GTK_ICON_SIZE_SMALL_TOOLBAR);
	widget = lookup_widget(lp_window_main, "lp_window_main_image_classes");
	gtk_image_set_from_stock (GTK_IMAGE(widget), "apple", GTK_ICON_SIZE_SMALL_TOOLBAR);
}

static void
lp_set_file_info(GtkWidget * lp_window_main, gchar *filename)
{
	gchar *filename_print; 
	if(strcmp(filename, filename_temp) == 0)
	{
		filename_print = "New Database";
	}
	else
	{
		filename_print = g_strdup(filename);
	}
	gtk_window_set_title(GTK_WINDOW(lp_window_main), g_strdup_printf("Lesson Plan 101 - %s", filename_print));
	
	GtkWidget *lp_window_main_label_filename = lookup_widget (GTK_WIDGET (lp_window_main), "lp_window_main_label_filename");
	gtk_label_set_text(GTK_LABEL(lp_window_main_label_filename), filename_print);
	
	GtkWidget *lp_window_main_label_filesize = lookup_widget (GTK_WIDGET (lp_window_main), "lp_window_main_label_filesize");
	struct stat statbuf;
	int rc = g_lstat (filename, &statbuf);
	if (rc > -1)
	{
		gtk_label_set_text(GTK_LABEL(lp_window_main_label_filesize), g_strdup_printf("size:%.1fkb", (float)statbuf.st_size/1024));		
	}
	else
	{
		gtk_label_set_text(GTK_LABEL(lp_window_main_label_filesize), "filesize unavailable");		
	}
}

void
lp_open_database (gchar * filename, GtkWidget * lp_window_main)
{
	lp_sql_open_database (filename);

	lp_set_file_info(lp_window_main, filename);
	lp_set_currentdate (lp_window_main);
}


static void
lp_sql_timestamp_triggers(gchar *table_name)
{
	/*triggers a function to automatically record a date that a row was inserted*/
	gchar *sql_template = g_strdup("CREATE TRIGGER %s_%s AFTER %s ON %s\
		BEGIN\
  		UPDATE %s SET %s = DATETIME('NOW','localtime')\
  		WHERE %s_id = %s.%s_id;\
		END;");
	gchar *sql_statement = g_strdup_printf(sql_template, table_name, "date_created", "INSERT", table_name, table_name, "date_created", table_name, "new", table_name);
	lp_sql_row_count(sql_statement);
	
	/*triggers a function to automatically record a date that a row was modified*/
	sql_statement = g_strdup_printf(sql_template, table_name, "date_modified", "UPDATE", table_name, table_name, "date_modified", table_name, "new", table_name);
	lp_sql_row_count(sql_statement);
}

void
lp_new_database (GtkWidget * lp_window_main)
{
	lp_sql_new_database ();

	gchar *sql_statement = g_strdup("CREATE TABLE 'option' (\
		option_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		option_name CHAR,\
		option_value INTEGER,\
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("option");
	
	sql_statement = g_strdup("CREATE TABLE 'dailyplan' (\
		dailyplan_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		dailyplan_date DATE,\
		dailyplan_description CHAR,\
		class_id INTEGER,\
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("dailyplan");

	sql_statement = g_strdup("CREATE TABLE 'weeklyplan' (\
		weeklyplan_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		weeklyplan_year INTEGER,\
		weeklyplan_week INTEGER,\
		weeklyplan_description CHAR,\
		class_id INTEGER,\
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("weeklyplan");	

	sql_statement = g_strdup("CREATE TABLE 'day' (\
		day_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		day_date DATE,\
		day_description CHAR,\
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("day");	
	
	sql_statement = g_strdup("CREATE TABLE 'week' (\
		week_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		week_year INTEGER,\
		week_week INTEGER,\
		week_description CHAR,\
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("week");
	
	sql_statement = g_strdup("CREATE TABLE 'class' (\
		class_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		class_name CHAR,\
		class_description CHAR,\
		class_order INTEGER, \
		class_startdate DATE,\
		class_enddate DATE,\
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("class");	
	sql_statement = g_strdup("CREATE TRIGGER class_startdate_trigger AFTER INSERT ON class\
		BEGIN\
  		UPDATE class SET class_startdate = DATE('NOW','localtime')\
  		WHERE class_id = new.class_id;\
		END;");
	lp_sql_row_count(sql_statement);
		sql_statement = g_strdup("CREATE TRIGGER class_enddate_trigger AFTER INSERT ON class\
		BEGIN\
  		UPDATE class SET class_enddate = DATE('NOW','localtime','+1 year')\
  		WHERE class_id = new.class_id;\
		END;");
	lp_sql_row_count(sql_statement);

	sql_statement = g_strdup("CREATE TABLE 'daylabel' (\
		daylabel_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		daylabel_name CHAR,\
		daylabel_order INTEGER, \
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("daylabel");	
	sql_statement =  g_strdup_printf("INSERT INTO %s ('%s_name') VALUES ('%s')", "daylabel", "daylabel", "No School");
		lp_sql_row_count(sql_statement);
	sql_statement =  g_strdup_printf("INSERT INTO %s ('%s_name') VALUES ('%s')", "daylabel", "daylabel", "Half-Day");
		lp_sql_row_count(sql_statement);

	sql_statement = g_strdup("CREATE TABLE 'weeklabel' (\
		weeklabel_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		weeklabel_name CHAR,\
		weeklabel_order INTEGER, \
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("daylabel");	
	sql_statement =  g_strdup_printf("INSERT INTO %s ('%s_name') VALUES ('%s')", "weeklabel", "weeklabel", "No School");
		lp_sql_row_count(sql_statement);

	sql_statement = g_strdup("CREATE TABLE 'dailyplanlabel' (\
		dailyplanlabel_id INTEGER PRIMARY KEY AUTOINCREMENT DEFAULT '0',\
		dailyplanlabel_name CHAR,\
		dailyplanlabel_order INTEGER, \
		date_created DATE,\
		date_modified DATE)"); 
	lp_sql_row_count(sql_statement);
	lp_sql_timestamp_triggers("dailyplanlabel");	

	lp_set_file_info(lp_window_main, filename_temp);
	lp_set_currentdate (lp_window_main);
}


gboolean
on_window_Main_delete_event (GtkWidget * widget,
			     GdkEvent * event, gpointer user_data)
{
  lp_sql_close_database();
  gtk_main_quit ();
  return FALSE;
}

void
lp_on_new_clicked                      (GtkWidget     *widget,
                                        gpointer         user_data)
{
	GtkWidget *lp_window_main = lookup_widget (widget, "lp_window_main");
	lp_new_database(lp_window_main);
}

static void
lp_initialize_dialog_filechooser(GtkWidget * lp_window_main)
{
	if (lp_dialog_filechooser == NULL)
    {
    	lp_dialog_filechooser = create_lp_dialog_filechooser ();
		gtk_window_set_transient_for(GTK_WINDOW(lp_dialog_filechooser), GTK_WINDOW(lp_window_main));

    	GtkFileFilter *filefilter = gtk_file_filter_new ();
    	gtk_file_filter_set_name (filefilter, "Lesson Plan (*.lp)");
    	gtk_file_filter_add_pattern (filefilter, "*.lp");
    	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER
				   (lp_dialog_filechooser), filefilter);
    	filefilter_selected = filefilter;

    	filefilter = gtk_file_filter_new ();
    	gtk_file_filter_set_name (filefilter, "All Files (*.*)");
    	gtk_file_filter_add_pattern (filefilter, "*");
    	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER
				   (lp_dialog_filechooser), filefilter);
				   
		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (lp_dialog_filechooser),
			       filefilter_selected);
		
		gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (lp_dialog_filechooser), TRUE);
    }	
}

void
lp_on_open_clicked                     (GtkWidget     *widget,
                                        gpointer         user_data)
{
	GtkWidget *lp_window_main = lookup_widget (GTK_WIDGET (widget), "lp_window_main");
	lp_initialize_dialog_filechooser(lp_window_main);
	
	GtkWidget *btn_ok = lookup_widget (GTK_WIDGET (lp_dialog_filechooser),
				     "lp_dialog_filechooser_btn_ok");
	gtk_button_set_label (GTK_BUTTON (btn_ok), "gtk-open");
	gtk_button_set_use_stock (GTK_BUTTON (btn_ok), TRUE);
	gtk_file_chooser_set_action (GTK_FILE_CHOOSER (lp_dialog_filechooser),
			       GTK_FILE_CHOOSER_ACTION_OPEN);

	gtk_window_set_title (GTK_WINDOW (lp_dialog_filechooser), "Open File");


	if (gtk_dialog_run (GTK_DIALOG (lp_dialog_filechooser)) == GTK_RESPONSE_OK)
    {
		gtk_widget_hide (lp_dialog_filechooser);
		// current_filename = g_strdup_printf("");
		gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(lp_dialog_filechooser));

		lp_open_database (filename, lp_window_main);
    	printf ("completed opening: %s\n", filename);
		g_free (filename);
    }
	filefilter_selected = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (lp_dialog_filechooser));
	gtk_widget_hide (lp_dialog_filechooser);
}


void
lp_on_save_clicked                     (GtkWidget     *widget,
                                        gpointer         user_data)
{
	GtkWidget *lp_window_main = lookup_widget (widget, "lp_window_main");
	if(filename_current == NULL)
	{
		lp_on_save_as_clicked(widget, user_data);
		return ;
	}
	lp_copy_file(filename_temp, filename_current);
	lp_set_file_info(lp_window_main, filename_current);
}


void
lp_on_save_as_clicked                  (GtkWidget     *widget,
                                        gpointer         user_data)
{
	GtkWidget *lp_window_main = lookup_widget (GTK_WIDGET (widget), "lp_window_main");
	lp_initialize_dialog_filechooser(lp_window_main);
	
	GtkWidget *btn_ok = lookup_widget (GTK_WIDGET (lp_dialog_filechooser),
				     "lp_dialog_filechooser_btn_ok");
	gtk_button_set_label (GTK_BUTTON (btn_ok), "gtk-save");
	gtk_button_set_use_stock (GTK_BUTTON (btn_ok), TRUE);
	gtk_file_chooser_set_action (GTK_FILE_CHOOSER (lp_dialog_filechooser), GTK_FILE_CHOOSER_ACTION_SAVE);

	gtk_window_set_title (GTK_WINDOW (lp_dialog_filechooser), "Save As...");
	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (lp_dialog_filechooser), TRUE);

	if (gtk_dialog_run (GTK_DIALOG (lp_dialog_filechooser)) == GTK_RESPONSE_OK)
    {
		gtk_widget_hide (lp_dialog_filechooser);
		// current_filename = g_strdup_printf("");
		gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(lp_dialog_filechooser));

		lp_copy_file(filename_temp, filename);
		filename_current = g_strdup(filename);
		lp_set_file_info(lp_window_main, filename_current);
    	printf ("completed saving: %s\n", filename);
    	g_free (filename);
    }
	filefilter_selected = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (lp_dialog_filechooser));
	gtk_widget_hide (lp_dialog_filechooser);
}


void
lp_on_close_clicked                    (GtkWidget     *widget,
                                        gpointer         user_data)
{

}




void
lp_on_export_clicked                   (GtkWidget     *widget,
                                        gpointer         user_data)
{
	//gchar *filename = g_strdup_printf("%s.html", tempnam(g_get_tmp_dir(), "lp101export_")) ;
	//printf("\n\n***temporary filename:%s\n", filename);
	//lp_export_to_html(widget, filename);
	//xhtmlite_open_website(filename);
	GtkWidget *dialog = create_lp_dialog_export();

	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), "Untitled.html");
    GtkFileFilter *filefilter_html = gtk_file_filter_new();
	gtk_file_filter_set_name(filefilter_html, "HTML (*.html,*.htm)");
	gtk_file_filter_add_pattern(filefilter_html, "*.html");
	gtk_file_filter_add_pattern(filefilter_html, "*.htm");
	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filefilter_html);
		
    GtkFileFilter *filefilter_all = gtk_file_filter_new();
	gtk_file_filter_set_name(filefilter_all, "All Files (*.*)");
	gtk_file_filter_add_pattern(filefilter_all, "*");
	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filefilter_all);
	
	gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
	
	if(gtk_dialog_run(GTK_DIALOG(dialog))==GTK_RESPONSE_OK)
	{
		gtk_widget_hide(dialog);
		gchar *filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER(dialog));
		lp_export_to_html(widget, filename);
		xhtmlite_open_website(filename);
	}
	gtk_widget_destroy(dialog);
}

void
lp_on_print_preview_clicked            (GtkWidget     *widget,
                                        gpointer         user_data)
{

}


void
lp_on_print_clicked                    (GtkWidget     *widget,
                                        gpointer         user_data)
{

}


void
lp_on_quit_clicked                     (GtkWidget     *widget,
                                        gpointer         user_data)
{
  gtk_main_quit ();
}


void
on_undo1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_redo1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_cut1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_copy1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_paste1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_delete1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_select_all1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_weekly_plans1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
	GtkWidget *lp_window_lesson = create_lp_window_lesson ();
	gtk_widget_show (lp_window_lesson);
}


void
on_lesson_plans1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_standards_list1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_find1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_search_database1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_use_filter1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_preferences1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
	GtkWidget * lp_window_main = lookup_widget(GTK_WIDGET(menuitem), "lp_window_main");        
	lp_setting_open(lp_window_main);
}


void
on_about1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
	GtkWidget *lp_dialog_about = create_lp_dialog_about();

	if (gtk_dialog_run (GTK_DIALOG (lp_dialog_about)) == GTK_RESPONSE_OK)
    {
    }
	gtk_widget_destroy (lp_dialog_about);
}


gboolean
on_window_Plan_delete_event (GtkWidget * widget,
			     GdkEvent * event, gpointer user_data)
{

  return FALSE;
}


void
lp_menuitem_on_forward_week_activate (GtkMenuItem * menuitem,
				      gpointer user_data)
{
  lp_on_forward_week_activate (GTK_WIDGET (menuitem));
}


void
lp_menuitem_on_back_week_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  lp_on_back_week_activate (GTK_WIDGET (menuitem));
}


void
lp_toolbtn_on_back_week_activate (GtkToolButton * toolbutton,
				  gpointer user_data)
{
  lp_on_back_week_activate (GTK_WIDGET (toolbutton));
}


void
lp_toolbtn_on_forward_week_activate (GtkToolButton * toolbutton,
				     gpointer user_data)
{
  lp_on_forward_week_activate (GTK_WIDGET (toolbutton));
}

void
lp_setting_button_day_label_on_clicked (GtkButton *button, gpointer user_data)
{
	GtkWidget *dialog = create_lp_dialog_field();
	lp_field_initialize(dialog, "daylabel", "Edit Day Labels", "Labels");
	
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
	{
		
	}
	gtk_widget_destroy(dialog);
}

void
lp_setting_button_week_label_on_clicked (GtkButton *button, gpointer user_data)
{
	GtkWidget *dialog = create_lp_dialog_field();
	lp_field_initialize(dialog, "weeklabel", "Edit Day Labels", "Labels");
	
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
	{
		
	}
	gtk_widget_destroy(dialog);
}

void
lp_edit_classes_on_clicked             (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	GtkWidget * lp_window_main = lookup_widget(GTK_WIDGET(menuitem), "lp_window_main");        
	lp_class_open(lp_window_main);
}


//static void
//draw_page (GtkPrintOperation *operation, GtkPrintContext *context, int page_nr)
//{
//	cairo_t *cr = gtk_print_context_get_cairo_context (context);
//	/* Draw a red rectangle, as wide as the paper (inside the margins) */
//	cairo_set_source_rgb (cr, 1.0, 0, 0);
//	cairo_rectangle (cr, 0, 0, gtk_print_context_get_width (context), 50);
//	cairo_fill (cr);
//	/* Draw path */
//	cairo_set_source_rgb (cr, 0, 0, 0);
//	cairo_move_to (cr, 90, 75);
//	cairo_line_to (cr, 60, 80);
//	cairo_curve_to (cr, 40, 70, 65, 65, 70, 60);
//	cairo_set_line_join (cr, CAIRO_LINE_JOIN_ROUND);
//	cairo_set_line_width (cr, 5);
//	cairo_stroke (cr);
//}


void
lp_print_on_clicked                    (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
//	GtkPrintOperation *op;
//	GtkPrintOperationResult res;
//	GtkPrintSettings *settings;
//	op = gtk_print_operation_new ();
//	settings = get_last_print_settings ();
//	gtk_print_operation_set_print_settings (op, settings);
//	gtk_print_operation_set_n_pages (op, 1);
//	gtk_print_operation_set_unit (op, GTK_UNIT_MM);
//	g_signal_connect (op, "draw_page", G_CALLBACK (draw_page), NULL);
//	res = gtk_print_operation_run (op, GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG, NULL, NULL);
//	if (res == GTK_PRINT_OPERATION_RESULT_APPLY) 
//	{
//		settings = gtk_print_operation_get_print_settings (op);
//		save_print_settings (settings);
//	}
}




void
lp_date_clicked                        (GtkWidget       *widget,
                                        gpointer         user_data)
{
    GtkWidget *lp_main_label_date = lookup_widget (widget, "lp_main_label_date");
  	GDate *old_date = g_object_get_data (G_OBJECT (lp_main_label_date), "date");

	GtkWidget *dialog = create_lp_dialog_date();
	GtkWidget *calendar = lookup_widget(dialog, "lp_calendar");
	/*gtk_calendar's month is from 0-11, but GDate's month is from 1-12 and 0 is a bad month.
		Therfore, I corrected this change by subtracting 1 for the calendar
		and then adding 1 back to the GDate*/
	printf("old_date: %d/%d/%d\n\n", g_date_get_year(old_date), g_date_get_month(old_date), g_date_get_day(old_date));	
	gtk_calendar_select_month(GTK_CALENDAR(calendar), g_date_get_month(old_date) - 1, g_date_get_year(old_date));
    gtk_calendar_select_day(GTK_CALENDAR(calendar), g_date_get_day(old_date));
  	g_signal_connect ((gpointer) calendar, "day_selected_double_click",
                    G_CALLBACK (lp_calendar_day_on_selected_double_click),
                    NULL);
  	
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
    {
		guint year, month, day;
		gtk_calendar_get_date(GTK_CALENDAR(calendar), &year, &month, &day);
		GDate *new_date = g_date_new_dmy(day, month + 1, year);
		printf("new_date: %d/%d/%d\n\n", year, month + 1, day);	
		lp_weekly_setup (widget, new_date);
    }
	gtk_widget_destroy (dialog);
}


void
lp_calendar_day_on_selected_double_click
                                        (GtkCalendar     *calendar,
                                        gpointer         user_data)
{
	GtkWidget *dialog = lookup_widget (GTK_WIDGET(calendar), "lp_dialog_date");
	gtk_dialog_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
}
