/*
 * lpclass.c
 * lessonplan
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */
 
#include <gtk/gtk.h>
#include "lpweekly.h"
#include "lpdate.h"

static GtkWidget * lp_window_class = NULL;
static gint lp_class_name_changed_id;
static gint lp_description_changed_id;
static gint lp_class_id_changed_id;

//TODO: Create date from and to for each class
static int
lp_class_record_number(GtkWidget *widget)
{
	GtkWidget *lp_class_label_record_number = lookup_widget (widget, "lp_class_label_record_number");        
	gchar *record_string = gtk_label_get_text(GTK_LABEL(lp_class_label_record_number));
	return atoi(record_string);  
}

static int
lp_class_record_count()
{
	gchar *sql_statement = g_strdup ("SELECT * FROM 'class'");
	int class_count = lp_sql_row_count(sql_statement); //Reset class count
	return class_count;  
}

static void
lp_class_name_changed(GtkEditable *editable, gpointer user_data)
{
	GtkWidget *lp_class_entry_record = lookup_widget (GTK_WIDGET(editable), "lp_class_entry_record");  
	const gchar *class_id = gtk_entry_get_text(GTK_ENTRY(lp_class_entry_record));
 
	GtkWidget *lp_class_entry_name = lookup_widget (GTK_WIDGET(editable), "lp_class_entry_name");  
	const gchar *new_text = gtk_entry_get_text(GTK_ENTRY(lp_class_entry_name));
      
	gchar *sql_statement;
	sql_statement = g_strdup_printf("UPDATE class SET class_name='%s' WHERE class_id='%s'", new_text, class_id);
	lp_sql_row_count(sql_statement);
}

static void
lp_class_id_changed(GtkEditable *editable, gpointer user_data)
{
	/** If this is used to change the class id, you must find the row number**/
	// GtkWidget * lp_class_entry_record = lookup_widget (GTK_WIDGET(editable), "lp_class_entry_record");  
	// gchar * class_id = gtk_entry_get_text(lp_class_entry_record);
}

static void
lp_class_buffer_changed(GtkTextBuffer *textbuffer, gpointer user_data)
{
	GtkWidget *lp_class_entry_record = lookup_widget (GTK_WIDGET(lp_window_class), "lp_class_entry_record");  
	const gchar *class_id = gtk_entry_get_text(GTK_ENTRY(lp_class_entry_record));
	
	GtkTextIter begin, end;
	gtk_text_buffer_get_bounds (textbuffer, &begin, &end);
	gchar * new_text = gtk_text_buffer_get_text (textbuffer, &begin, &end, TRUE);
	      
	gchar *sql_statement;
	sql_statement = g_strdup_printf("UPDATE class SET class_description='%s' WHERE class_id='%s'", new_text, class_id);
	lp_sql_row_count(sql_statement); 
}

static void
lp_class_set_date_label(GtkWidget *date_label, gchar *column_name, int record)
{
	
	gchar *sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", record-1); 
	gchar *value = g_strdup((gchar *)lp_sql_value(sql_statement, column_name));
	gchar *date_string = lp_date_get_date_string_from_sqlite_format(value);
	g_free(sql_statement);
	g_free(value);
	if(date_string != NULL)
	{
		gtk_label_set_text(GTK_LABEL(date_label), date_string);		
	}
	else
	{
		printf("date not valid\n");
	}
}

static void
lp_class_record_changed(GtkWidget *widget, int record)
{
 //set record number
	GtkWidget *lp_class_label_record_number = lookup_widget (widget, "lp_class_label_record_number");        
	gtk_label_set_text(GTK_LABEL(lp_class_label_record_number), g_strdup_printf("%d", record));

 //set record count
	int record_count = lp_class_record_count();
	GtkWidget *lp_class_label_record_count = lookup_widget (widget, "lp_class_label_record_count");        
	gtk_label_set_text(GTK_LABEL(lp_class_label_record_count), g_strdup_printf("%d", record_count));

 //set Class name
	GtkWidget *lp_class_entry_name = lookup_widget (widget, "lp_class_entry_name");  
	gchar *sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", record-1); 
	gchar *column_name = g_strdup("class_name"); 
	gchar *value = g_strdup((gchar *)lp_sql_value(sql_statement, column_name));
	g_signal_handler_disconnect ((gpointer) lp_class_entry_name, lp_class_name_changed_id);
	gtk_entry_set_text(GTK_ENTRY(lp_class_entry_name), value);
	lp_class_name_changed_id = g_signal_connect ((gpointer) lp_class_entry_name, "changed",
	                G_CALLBACK (lp_class_name_changed), NULL);

 //set Class Description
	GtkWidget * lp_class_textview_description = lookup_widget (widget, "lp_class_textview_description"); 
	GtkTextBuffer *lp_class_buffer_description = gtk_text_view_get_buffer (GTK_TEXT_VIEW(lp_class_textview_description));
	sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", record-1); 
	column_name = g_strdup("class_description"); 
	value = g_strdup((gchar *)lp_sql_value(sql_statement, column_name)); 
	if(value == NULL) value = g_strdup("");
	g_signal_handler_disconnect ((gpointer) lp_class_buffer_description, lp_description_changed_id);
	gtk_text_buffer_set_text (lp_class_buffer_description, value, -1);
	lp_description_changed_id = g_signal_connect ((gpointer) lp_class_buffer_description, "changed",
					       G_CALLBACK (lp_class_buffer_changed), NULL);
 
 //set Record ID
	GtkWidget *lp_class_entry_record = lookup_widget (widget, "lp_class_entry_record");  
	sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", record-1); 
	column_name = g_strdup("class_id"); 
	value = g_strdup((gchar *)lp_sql_value(sql_statement, column_name));
	gtk_entry_set_text(GTK_ENTRY(lp_class_entry_record), value);
 
 //set startdate
	GtkWidget *lp_class_startdate = lookup_widget (widget, "lp_class_startdate");  
	column_name = g_strdup("class_startdate"); 
	lp_class_set_date_label(lp_class_startdate, column_name, record);
	
 //set enddate
	GtkWidget *lp_class_enddate = lookup_widget (widget, "lp_class_enddate");  
	column_name = g_strdup("class_enddate"); 
	lp_class_set_date_label(lp_class_enddate, column_name, record);
	
 //enable or disable the proper buttons
	GtkWidget *lp_class_toolbutton_first = lookup_widget (lp_window_class, "lp_class_toolbutton_first");
	GtkWidget *lp_class_toolbutton_back = lookup_widget (lp_window_class, "lp_class_toolbutton_back");
	if (record > 1)
	{
		gtk_widget_set_sensitive (lp_class_toolbutton_first, TRUE);
		gtk_widget_set_sensitive (lp_class_toolbutton_back, TRUE);
	}
	else
	{
		gtk_widget_set_sensitive (lp_class_toolbutton_first, FALSE);
		gtk_widget_set_sensitive (lp_class_toolbutton_back, FALSE);
	}
	GtkWidget *lp_class_toolbutton_forward = lookup_widget (lp_window_class, "lp_class_toolbutton_forward");
	GtkWidget *lp_class_toolbutton_last = lookup_widget (lp_window_class, "lp_class_toolbutton_last");
	if (record < record_count)
	{
		gtk_widget_set_sensitive (lp_class_toolbutton_forward, TRUE);
		gtk_widget_set_sensitive (lp_class_toolbutton_last, TRUE);
	}
	else
	{
		gtk_widget_set_sensitive (lp_class_toolbutton_forward, FALSE);
		gtk_widget_set_sensitive (lp_class_toolbutton_last, FALSE);
	}
	GtkWidget *lp_class_toolbutton_delete = lookup_widget (lp_window_class, "lp_class_toolbutton_delete");        
	if (record_count > 0)
	{
		gtk_widget_set_sensitive (lp_class_toolbutton_delete, TRUE);
	}
	else
	{
		gtk_widget_set_sensitive (lp_class_toolbutton_delete, FALSE);
	}
}

static void
lp_class_first(GtkToolButton *toolbutton, gpointer user_data)
{
	int record = 1;
	lp_class_record_changed(GTK_WIDGET(toolbutton), record);
}

static void
lp_class_back(GtkToolButton *toolbutton, gpointer user_data)
{
	int record = lp_class_record_number(GTK_WIDGET(toolbutton)) - 1;
	if(record < 1)
	{
		record = 1;
	}
	lp_class_record_changed(GTK_WIDGET(toolbutton), record);
}

static void
lp_class_forward(GtkToolButton *toolbutton, gpointer user_data)
{
	int record = lp_class_record_number(GTK_WIDGET(toolbutton)) + 1;
	int record_count = lp_class_record_count();
	if(record > record_count)
	{
		record = record_count;
	}
	lp_class_record_changed(GTK_WIDGET(toolbutton), record);
}

static void
lp_class_last(GtkToolButton *toolbutton, gpointer user_data)
{
	int record_count = lp_class_record_count();
	lp_class_record_changed(GTK_WIDGET(toolbutton), record_count);
}

static void
lp_class_new(GtkToolButton *toolbutton, gpointer user_data)
{
	gchar * sql_statement = g_strdup_printf("INSERT INTO 'class' ('class_name') VALUES ('')");
	lp_sql_row_count(sql_statement);
	
	int record_count = lp_class_record_count();
	lp_class_record_changed(GTK_WIDGET(toolbutton), record_count);
}

static void
lp_class_delete(GtkToolButton *toolbutton, gpointer user_data)
{
	GtkWidget *dialog = create_lp_dialog_class_delete(); 
	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(lp_window_class));
	
	//get record information
	GtkWidget *lp_class_entry_record = lookup_widget (GTK_WIDGET(toolbutton), "lp_class_entry_record");  
	const gchar *class_id = gtk_entry_get_text(GTK_ENTRY(lp_class_entry_record));
	
	GtkWidget *lp_class_entry_name = lookup_widget (GTK_WIDGET(toolbutton), "lp_class_entry_name");  
	gchar *class_name = gtk_entry_get_text(GTK_ENTRY(lp_class_entry_name));
	
	GtkWidget *lp_class_textview_description = lookup_widget (GTK_WIDGET(toolbutton), "lp_class_textview_description"); 
	GtkTextBuffer *lp_class_buffer_description = gtk_text_view_get_buffer (GTK_TEXT_VIEW(lp_class_textview_description));
	GtkTextIter begin, end;
	gtk_text_buffer_get_bounds (lp_class_buffer_description, &begin, &end);
	gchar *class_description = gtk_text_buffer_get_text (lp_class_buffer_description, &begin, &end, TRUE);
	
	//set dialog information
	GtkWidget *lp_class_delete_label_name = lookup_widget (dialog, "lp_class_delete_label_name");  
	gtk_label_set_text(GTK_LABEL(lp_class_delete_label_name), g_strdup_printf("%s (Record ID#: %s)", class_name, class_id));
	
	GtkWidget *lp_class_delete_label_description = lookup_widget (dialog, "lp_class_delete_label_description");  
	gtk_label_set_text(GTK_LABEL(lp_class_delete_label_description), class_description);
	
	//run dialog
	if (gtk_dialog_run (GTK_DIALOG(dialog)) == GTK_RESPONSE_OK)
	{     
		gchar *sql_statement;
		sql_statement = g_strdup_printf("DELETE from class WHERE class_id='%s'", class_id);
		lp_sql_row_count(sql_statement);
		
		int record = lp_class_record_number(GTK_WIDGET(toolbutton)) - 1;
		if(record < 1) record = 1;
		lp_class_record_changed(GTK_WIDGET(toolbutton), record);
	}
	gtk_widget_destroy(dialog);
}


static void
lp_class_calendar_double_click (GtkCalendar *calendar, GtkWidget *dialog)
{
	gtk_dialog_response(GTK_DIALOG(dialog), GTK_RESPONSE_OK);
}


static void
lp_class_date_clicked(GtkWidget *widget, gchar *column_name)
{
	GtkWidget *date_label = lookup_widget (lp_window_class, g_strdup_printf("lp_%s", column_name)); 

  	GDate *old_date = g_date_new();
	const gchar *datestring = gtk_label_get_text(GTK_LABEL(date_label));
	g_date_set_parse(old_date, datestring);

	GtkWidget *dialog = create_lp_dialog_date();
	GtkWidget *calendar = lookup_widget(dialog, "lp_calendar");
	/*gtk_calendar's month is from 0-11, but GDate's month is from 1-12 and 0 is a bad month.
		Therfore, I corrected this change by subtracting 1 for the calendar
		and then adding 1 back to the GDate*/
	printf("old_date: %d/%d/%d\n\n", g_date_get_year(old_date), g_date_get_month(old_date), g_date_get_day(old_date));	
	gtk_calendar_select_month(GTK_CALENDAR(calendar), g_date_get_month(old_date) - 1, g_date_get_year(old_date));
    gtk_calendar_select_day(GTK_CALENDAR(calendar), g_date_get_day(old_date));
  	g_signal_connect ((gpointer) calendar, "day_selected_double_click",
                    G_CALLBACK (lp_class_calendar_double_click),
                    dialog);
  	
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
    {
		guint year, month, day;
		gtk_calendar_get_date(GTK_CALENDAR(calendar), &year, &month, &day);
		GDate *mydate = g_date_new_dmy(day, month + 1, year);
		printf("new_date: %d/%d/%d\n\n", year, month + 1, day);	
		gtk_label_set_text(GTK_LABEL(date_label), lp_date_get_date_string(mydate));
		
		GtkWidget *lp_class_entry_record = lookup_widget (GTK_WIDGET(lp_window_class), "lp_class_entry_record");  
		const gchar *class_id = gtk_entry_get_text(GTK_ENTRY(lp_class_entry_record));
		
	    gchar *sql_statement;
	    gchar *sql_date_string = g_strdup_printf("%d-%d-%d", g_date_get_year(mydate), g_date_get_month(mydate), g_date_get_day(mydate));
		sql_statement = g_strdup_printf("UPDATE class SET %s='%s' WHERE class_id='%s'", column_name, sql_date_string, class_id);
		lp_sql_row_count(sql_statement); 
		
		g_date_free(mydate);
    }
    g_date_free(old_date);
	gtk_widget_destroy (dialog);
}


static void
lp_class_close(GtkToolButton *toolbutton, gpointer user_data)
{
	gtk_widget_hide(lp_window_class);
	GtkWidget * lp_window_main = GTK_WIDGET(user_data);
	lp_weekly_setup(lp_window_main, NULL);
}

static void
lp_class_destroy(GtkWidget *widget, gpointer user_data)
{
	GtkWidget * lp_window_main = GTK_WIDGET(user_data);
	lp_weekly_setup(lp_window_main, NULL);
	lp_window_class = NULL;
}

void 
lp_class_open(GtkWidget *lp_window_main)
{
	if(lp_window_class == NULL)
	{
		lp_window_class = create_lp_window_class();
		
		gtk_window_set_transient_for(GTK_WINDOW(lp_window_class), GTK_WINDOW(lp_window_main));
		
		GtkWidget *lp_class_toolbutton_first = lookup_widget (lp_window_class, "lp_class_toolbutton_first");
		GtkWidget *lp_class_toolbutton_back = lookup_widget (lp_window_class, "lp_class_toolbutton_back");
		GtkWidget *lp_class_toolbutton_forward = lookup_widget (lp_window_class, "lp_class_toolbutton_forward");
		GtkWidget *lp_class_toolbutton_last = lookup_widget (lp_window_class, "lp_class_toolbutton_last");
		GtkWidget *lp_class_toolbutton_new = lookup_widget (lp_window_class, "lp_class_toolbutton_new");        
		GtkWidget *lp_class_toolbutton_delete = lookup_widget (lp_window_class, "lp_class_toolbutton_delete");        
		GtkWidget *lp_class_toolbutton_close = lookup_widget (lp_window_class, "lp_class_toolbutton_close");        
		GtkWidget *lp_class_entry_name = lookup_widget (lp_window_class, "lp_class_entry_name");  
		GtkWidget *lp_class_entry_record = lookup_widget (lp_window_class, "lp_class_entry_record");  
		GtkWidget *lp_class_textview_description = lookup_widget (lp_window_class, "lp_class_textview_description"); 
		GtkTextBuffer *lp_class_buffer_description = gtk_text_view_get_buffer (GTK_TEXT_VIEW(lp_class_textview_description));
		GtkWidget *lp_class_button_startdate = lookup_widget (lp_window_class, "lp_class_button_startdate"); 
		GtkWidget *lp_class_button_enddate = lookup_widget (lp_window_class, "lp_class_button_enddate"); 

		
		g_signal_connect ((gpointer) lp_class_toolbutton_first, "clicked",
		                G_CALLBACK (lp_class_first), NULL);
		g_signal_connect ((gpointer) lp_class_toolbutton_back, "clicked",
		                G_CALLBACK (lp_class_back), NULL);
		g_signal_connect ((gpointer) lp_class_toolbutton_forward, "clicked",
		                G_CALLBACK (lp_class_forward), NULL);
		g_signal_connect ((gpointer) lp_class_toolbutton_last, "clicked",
		                G_CALLBACK (lp_class_last), NULL);
		g_signal_connect ((gpointer) lp_class_toolbutton_new, "clicked",
		                G_CALLBACK (lp_class_new), NULL);
		g_signal_connect ((gpointer) lp_class_toolbutton_delete, "clicked",
		                G_CALLBACK (lp_class_delete), NULL);
		g_signal_connect ((gpointer) lp_class_toolbutton_close, "clicked",
		                G_CALLBACK (lp_class_close), lp_window_main);
		g_signal_connect ((gpointer) lp_class_button_startdate, "clicked",
		                G_CALLBACK (lp_class_date_clicked), g_strdup("class_startdate"));
		g_signal_connect ((gpointer) lp_class_button_enddate, "clicked",
		                G_CALLBACK (lp_class_date_clicked), g_strdup("class_enddate"));
														
		lp_class_name_changed_id = g_signal_connect ((gpointer) lp_class_entry_name, "changed",
		                G_CALLBACK (lp_class_name_changed), NULL);
		lp_class_id_changed_id = g_signal_connect ((gpointer) lp_class_entry_name, "changed",
		                G_CALLBACK (lp_class_id_changed), NULL);
		lp_description_changed_id = g_signal_connect ((gpointer) lp_class_buffer_description, "changed",
						       G_CALLBACK (lp_class_buffer_changed), NULL);
		
		g_signal_connect ((gpointer) lp_window_class, "destroy",
		                G_CALLBACK (lp_class_destroy), lp_window_main);
		
		int record_count = lp_class_record_count();
		if(record_count > 0)
		{
		    lp_class_record_changed(lp_window_class, 1); 
		}
	}
	gtk_widget_show(lp_window_class);
}
