/*
 * lpfield.c
 * lessonplan
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */
  
#include <gtk/gtk.h>
#include "lpfield.h"
#include "lpsql.h"

static gchar *table_name = NULL;

static void
lp_field_cell_edited (GtkCellRendererText *cell, gchar *path_string, gchar *new_string, gpointer data)
{
	printf("Cell Edited, %s, %s\n", path_string, new_string);
	          
	GtkTreeModel *tree_model = GTK_TREE_MODEL(data);
	GtkTreeIter iter;
	
	//gint column = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (cell), "column"));
	gtk_tree_model_get_iter_from_string (tree_model, &iter, path_string);

	
	if(gtk_tree_store_iter_is_valid    (GTK_TREE_STORE(tree_model),&iter))
	{
		gchar *old_string;
		gchar *id;
		gtk_tree_model_get (tree_model, &iter, FIELD_NAME_COLUMN, &old_string, -1);
		/*find if string changed to see if we need to store the undo*/
		if(strcmp(old_string, new_string) != 0  && strcmp("New Value", new_string) != 0)
		{
			//byoj_undo_add_undo(UNDO_EDIT, &iter);
			gchar *sql_statement = NULL;
			if(strcmp("New Value", old_string) == 0)
			{
				printf("%s", table_name);
				sql_statement =  g_strdup_printf("INSERT INTO %s ('%s_name') VALUES ('%s')", table_name, table_name, new_string);
				id = lp_sql_value(sql_statement, g_strdup_printf("%s_id", table_name));
				gtk_tree_store_set (GTK_TREE_STORE(tree_model), &iter,
						FIELD_ID_COLUMN, id,
						-1);
			}
			else
			{
				gtk_tree_model_get (tree_model, &iter, FIELD_ID_COLUMN, &id, -1);
				sql_statement = g_strdup_printf("UPDATE %s SET %s_name='%s' WHERE %s_id = '%s'", table_name, table_name, new_string, table_name, id);
				lp_sql_row_count(sql_statement);
			}
			gtk_tree_store_set (GTK_TREE_STORE (tree_model), &iter, FIELD_NAME_COLUMN, new_string, -1);
		}
	}
}

static void
lp_field_add_on_clicked (GtkWidget *widget, gpointer data)
{
	//gchar *sql_statement =  g_strdup_printf("INSERT INTO %s ('name') VALUES ('New Value')", table_name);
	GtkTreeStore *store = GTK_TREE_STORE(data);
	GtkTreeIter iter;
	gtk_tree_store_append (store, &iter, NULL);
	gtk_tree_store_set (store, &iter,
						FIELD_NAME_COLUMN, "New Value",
						FIELD_NAME_EDITABLE, TRUE,
						-1);
}
 
static void
lp_field_edit_on_clicked (GtkWidget *widget, gpointer table_name)
{
	/* TODO (#2#): Fix offset of editing entry box */
	GtkWidget *treeview = lookup_widget(widget, "lp_dialog_field_treeview");
	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	GtkTreeIter iter;
	if(gtk_tree_selection_get_selected (selection, &model, &iter))
	{
		gtk_tree_view_set_cursor (GTK_TREE_VIEW(treeview), gtk_tree_model_get_path(model, &iter),
					gtk_tree_view_get_column (GTK_TREE_VIEW(treeview), 0),  TRUE);
	}
}

static void
lp_field_delete_on_clicked (GtkWidget *widget, gpointer table_name)
{
	GtkWidget *treeview = lookup_widget(widget, "lp_dialog_field_treeview");
	GtkTreeModel *model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
	GtkTreeSelection *selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	GtkTreeIter iter;
	if(gtk_tree_selection_get_selected (selection, &model, &iter))
	{
		gchar *old_string;
		gtk_tree_model_get (model, &iter, FIELD_NAME_COLUMN, &old_string, -1);
		GtkWidget *lp_dialog_field = lookup_widget(widget, "lp_dialog_field");
		GtkWidget *dialog = gtk_message_dialog_new (lp_dialog_field,
                                  GTK_DIALOG_DESTROY_WITH_PARENT,
                                  GTK_MESSAGE_QUESTION,
                                  GTK_BUTTONS_OK_CANCEL,
                                  "Are you sure you want to delete this row: '%s'?",
									old_string);
 		if(gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
 		{
			gchar *id;
			gtk_tree_model_get (model, &iter, FIELD_ID_COLUMN, &id, -1);
			gchar *sql_statement = g_strdup_printf("DELETE FROM %s WHERE %s_id = '%s'", table_name, table_name, id);
	    	lp_sql_row_count(sql_statement);
	    	gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
		}
		gtk_widget_destroy (dialog);
	}
}

static void
lp_field_fill_treeview(GtkTreeStore *store)
{
	gchar *sql_statement = g_strdup_printf("SELECT * FROM %s", table_name);
	int row_count = lp_sql_row_count(sql_statement);
	if (row_count > 0)
	{
		int n;
		for(n=0; n<row_count; n++)
		{
			sql_statement = g_strdup_printf("SELECT * FROM %s LIMIT 1 OFFSET %d", table_name, n);
			gchar *id = lp_sql_value(sql_statement, g_strdup_printf("%s_id", table_name));
			gchar *name = lp_sql_value(sql_statement, g_strdup_printf("%s_name", table_name));			
			GtkTreeIter iter;
			gtk_tree_store_append (store, &iter, NULL);
			gtk_tree_store_set (store, &iter,
						FIELD_NAME_COLUMN, name,
						FIELD_NAME_EDITABLE, TRUE,
						FIELD_ID_COLUMN, id,
						-1);
		}
	}
}

void
lp_field_initialize(GtkWidget *dialog, gchar *sql_table_name, gchar *window_name, gchar *list_name)
{
	/*Change Dialog Labels together*/
	table_name = g_strdup(sql_table_name);
	gtk_window_set_title(GTK_WINDOW(dialog), g_strdup(window_name));
	GtkWidget *label = lookup_widget (dialog, "lp_dialog_field_label");
	gtk_label_set_markup(GTK_LABEL(label), g_strdup_printf("<b>%s</b>", list_name));

	/*Prepare the treeview and treestore*/		
	GtkWidget *treeview = lookup_widget (dialog, "lp_dialog_field_treeview");
	GtkTreeStore *store = gtk_tree_store_new (4,
				GDK_TYPE_PIXBUF,
				G_TYPE_STRING,
				G_TYPE_BOOLEAN, 
				G_TYPE_STRING, -1);
	gtk_tree_view_set_model(GTK_TREE_VIEW(treeview), GTK_TREE_MODEL(store));
	
	GtkCellRenderer *renderer_image = gtk_cell_renderer_pixbuf_new ();
	//g_object_set_data(G_OBJECT (renderer_image), "stock-size", 1);

	GtkCellRenderer *renderer_name = gtk_cell_renderer_text_new ();
	g_signal_connect (renderer_name, "edited", G_CALLBACK (lp_field_cell_edited), store);

	//GtkCellRenderer *renderer_id = gtk_cell_renderer_text_new ();
	//g_object_set_data (G_OBJECT (renderer_id), "column", 0);


	GtkTreeViewColumn *column = gtk_tree_view_column_new ();
	gtk_tree_view_column_set_title(column, "Name");
	gtk_tree_view_column_pack_start (column, renderer_image, FALSE);
	gtk_tree_view_column_add_attribute (column, renderer_image, "pixbuf", FIELD_IMAGE_COLUMN);
	gtk_tree_view_column_pack_start (column, renderer_name, TRUE);
	gtk_tree_view_column_add_attribute (column, renderer_name, "text", FIELD_NAME_COLUMN);
	gtk_tree_view_column_add_attribute (column, renderer_name, "editable", FIELD_NAME_EDITABLE);
	//gtk_tree_view_column_add_attribute (column, renderer_id, "text", FIELD_ID_COLUMN);
	//gtk_tree_view_column_set_expand (column, TRUE);
	//gtk_tree_view_column_set_resizable(column, TRUE);
	gtk_tree_view_column_set_sort_column_id(column, 0);
	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
	//gtk_tree_view_column_set_reorderable(TopicCol, TRUE);
	//gtk_tree_view_column_set_visible (TopicCol, TRUE);

	gtk_tree_view_column_set_sort_column_id(column, FIELD_NAME_COLUMN);
	
	/*Add the button callbacks*/
	GtkWidget *button = lookup_widget (dialog, "lp_dialog_field_toolbutton_add");
	g_signal_connect ((gpointer) button, "clicked",
                    G_CALLBACK (lp_field_add_on_clicked),
                    store);
                    
    button = lookup_widget (dialog, "lp_dialog_field_toolbutton_edit");
    g_signal_connect ((gpointer) button, "clicked",
                    G_CALLBACK (lp_field_edit_on_clicked),
                    table_name);
                    
    button = lookup_widget (dialog, "lp_dialog_field_toolbutton_delete");
	g_signal_connect ((gpointer) button, "clicked",
                    G_CALLBACK (lp_field_delete_on_clicked),
                    table_name);
	
	
	/*Fill the treeview*/
	lp_field_fill_treeview(store);
}
