/*
 * lpsetting.c
 * lessonplan
 * This file is for the settings or preferences dialog.
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */
 
#include <gtk/gtk.h>
#include "lpoptions.h"

static GtkWidget * lp_dialog_setting = NULL;

static int
lp_setting_toggle_button_get_active(GtkWidget * togglebutton)
{
	int value = 0;
	if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)))
	{
		value = 1;
	}  
	printf("value = %d\n", value);
	return value;
}

static void
lp_setting_checkbutton_show_weekly_plan_on_toggled (GtkToggleButton *togglebutton, gpointer user_data)
{
    GtkWidget *lp_setting_radiobutton_show_weekly_end = lookup_widget (GTK_WIDGET(togglebutton), "lp_setting_radiobutton_show_weekly_end");     
    GtkWidget *lp_setting_radiobutton_show_weekly_start = lookup_widget (GTK_WIDGET(togglebutton), "lp_setting_radiobutton_show_weekly_start");    
	gtk_widget_set_sensitive (lp_setting_radiobutton_show_weekly_end, gtk_toggle_button_get_active(togglebutton));
	gtk_widget_set_sensitive (lp_setting_radiobutton_show_weekly_start, gtk_toggle_button_get_active(togglebutton));
}

void 
lp_setting_open(GtkWidget * lp_window_main)
{
 if(lp_dialog_setting == NULL)
 {
    lp_dialog_setting = create_lp_dialog_setting();
    gtk_window_set_transient_for(GTK_WINDOW(lp_dialog_setting), GTK_WINDOW(lp_window_main));

    GtkWidget *show_weekly_plan = lookup_widget (lp_dialog_setting, "lp_setting_checkbutton_show_weekly_plan"); 
    g_signal_connect ((gpointer) show_weekly_plan, "toggled",
                    G_CALLBACK (lp_setting_checkbutton_show_weekly_plan_on_toggled),
                    NULL);
 }
 
    GtkWidget *lp_setting_radiobutton_show_dates_top = lookup_widget (lp_dialog_setting, "lp_setting_radiobutton_show_dates_top");
    GtkWidget *lp_setting_radiobutton_show_dates_left = lookup_widget (lp_dialog_setting, "lp_setting_radiobutton_show_dates_left");
    GtkWidget *lp_setting_radiobutton_show_week = lookup_widget (lp_dialog_setting, "lp_setting_radiobutton_show_week");
    GtkWidget *lp_setting_radiobutton_show_month = lookup_widget (lp_dialog_setting, "lp_setting_radiobutton_show_month");
    GtkWidget *lp_setting_comboboxentry_start_week = lookup_widget (lp_dialog_setting, "lp_setting_comboboxentry_start_week");        
    GtkWidget *lp_setting_checkbox_monday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_monday");        
    GtkWidget *lp_setting_checkbox_tuesday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_tuesday");        
    GtkWidget *lp_setting_checkbox_wednesday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_wednesday");  
    GtkWidget *lp_setting_checkbox_thursday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_thursday");  
    GtkWidget *lp_setting_checkbox_friday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_friday"); 
    GtkWidget *lp_setting_checkbox_saturday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_saturday"); 
    GtkWidget *lp_setting_checkbox_sunday = lookup_widget (lp_dialog_setting, "lp_setting_checkbox_sunday"); 
    GtkWidget *lp_setting_checkbutton_show_weekly_plan = lookup_widget (lp_dialog_setting, "lp_setting_checkbutton_show_weekly_plan"); 
    GtkWidget *lp_setting_radiobutton_show_weekly_end = lookup_widget (lp_dialog_setting, "lp_setting_radiobutton_show_weekly_end");     
    GtkWidget *lp_setting_radiobutton_show_weekly_start = lookup_widget (lp_dialog_setting, "lp_setting_radiobutton_show_weekly_start");    

       /*get the show_dates radiobutton set*/
       if (lp_options_get_show_dates_left(-1))
       {
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_radiobutton_show_dates_left), TRUE); 
       }
       else
       {
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_radiobutton_show_dates_top), TRUE);          
       }

       /*get the show week or month radiobutton set*/
       if (lp_options_show_month(-1))
       {
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_radiobutton_show_month), TRUE);  
       }
       else
       {
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_radiobutton_show_week), TRUE);
       }

		/*get the show weekly plan checkbutton set*/
    	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbutton_show_weekly_plan), lp_options_show_weekly_plan(-1)); 
    	lp_setting_checkbutton_show_weekly_plan_on_toggled(GTK_TOGGLE_BUTTON(lp_setting_checkbutton_show_weekly_plan), NULL);
		/*get the show weekly plan at the start radiobutton set*/
    	if (lp_options_show_weekly_at_start(-1))
    	{
    		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_radiobutton_show_weekly_start), TRUE);  
    	}
    	else
    	{
			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_radiobutton_show_weekly_end), TRUE);
		}

       /*get the first weekday comboboxentry*/
       gtk_combo_box_set_active (GTK_COMBO_BOX(lp_setting_comboboxentry_start_week), lp_options_get_weekday_first(-1)-1);

       /*get hide dates*/
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_monday), lp_options_hide_monday(-1)); 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_tuesday), lp_options_hide_tuesday(-1)); 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_wednesday), lp_options_hide_wednesday(-1)); 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_thursday), lp_options_hide_thursday(-1)); 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_friday), lp_options_hide_friday(-1)); 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_saturday), lp_options_hide_saturday(-1)); 
       gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lp_setting_checkbox_sunday), lp_options_hide_sunday(-1)); 
       
  	if (gtk_dialog_run (GTK_DIALOG (lp_dialog_setting)) == GTK_RESPONSE_OK)
	{
       /*set the show_dates radiobutton set*/
       lp_options_get_show_dates_left(lp_setting_toggle_button_get_active(lp_setting_radiobutton_show_dates_left)); 

       /*set the show week or month radiobutton*/
       lp_options_show_month(lp_setting_toggle_button_get_active(lp_setting_radiobutton_show_month)); 

       /*set the first weekday comboboxentry*/
       lp_options_get_weekday_first(gtk_combo_box_get_active(GTK_COMBO_BOX(lp_setting_comboboxentry_start_week))+1); 

       /* set hide dates*/
		lp_options_hide_monday(lp_setting_toggle_button_get_active(lp_setting_checkbox_monday));
		lp_options_hide_tuesday(lp_setting_toggle_button_get_active(lp_setting_checkbox_tuesday));
		lp_options_hide_wednesday(lp_setting_toggle_button_get_active(lp_setting_checkbox_wednesday));
		lp_options_hide_thursday(lp_setting_toggle_button_get_active(lp_setting_checkbox_thursday));
		lp_options_hide_friday(lp_setting_toggle_button_get_active(lp_setting_checkbox_friday));
		lp_options_hide_saturday(lp_setting_toggle_button_get_active(lp_setting_checkbox_saturday));
		lp_options_hide_sunday(lp_setting_toggle_button_get_active(lp_setting_checkbox_sunday));

		/*set the show weekly plan checkbox*/
		lp_options_show_weekly_plan(lp_setting_toggle_button_get_active(lp_setting_checkbutton_show_weekly_plan)); 
    	/*set the show weekly plan radiobutton set*/
    	lp_options_show_weekly_at_start(lp_setting_toggle_button_get_active(lp_setting_radiobutton_show_weekly_start));
		
		
       lp_weekly_setup(lp_window_main, NULL);
    }
    gtk_widget_hide(lp_dialog_setting);
}
