/*
 * lpsql.c
 * lessonplan
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */
#include <sqlite3.h>
#include <gtk/gtk.h>
#include "lpsql.h"

//following can be replaced by #include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>

static sqlite3 *db;

static int row_count = 0;
static gchar * col_name;
static gchar * value_string;
static gchar * row_number;

int
lp_copy_file (char *filename_old, char *filename_new)
{
  FILE *in, *out;
  char ch;

  if((in=fopen(filename_old, "rb")) == NULL) {
    printf("Cannot open input file.\n");
    exit(1);
  }
  if((out=fopen(filename_new, "wb")) == NULL) {
    printf("Cannot open output file.\n");
    exit(1);
  }

  while(!feof(in)) {
    ch = getc(in);
    if(ferror(in)) {
      printf("Read Error");
      clearerr(in);
      break;
    } else {
      if(!feof(in)) putc(ch, out);
      if(ferror(out)) {
        printf("Write Error");
        clearerr(out);
        break;
      }
    }
  }
  fclose(in);
  fclose(out);

	printf("finished copy\n");
  return 0;
}

static gchar*
lp_sql_get_temp_filename()
{
	gchar *filename = g_strdup_printf("%s", tempnam(g_get_tmp_dir(), "lp101_")) ;
	printf("\n\n***temporary filename:%s\n", filename);
	return filename;	
}

static int
lp_sql_row_callback (void *NotUsed, int argc, char **argv,
			     char **azColName)
{
  int i;
  for (i = 0; i < argc; i++)
    {
      printf ("%s = %s\n", azColName[i], argv[i] ? argv[i] : "NULL");
      if(strcmp(azColName[i],col_name)==0)
      {
      //get the selected values
        value_string = g_strdup(argv[i]);  
      }
    }
    row_count += 1;
  return 0;
}

void
lp_sql_close_database ()
{
	int rc = SQLITE_OK;
	rc =  sqlite3_close (db);
	if (rc != SQLITE_OK)
    {
    	fprintf (stderr, "Can't close database: %s\n", sqlite3_errmsg (db));
    	return ;
    }
    filename_current = NULL;
}

void
lp_sql_new_database ()
{
	lp_sql_close_database();
	
	int rc = SQLITE_OK;
	filename_temp = lp_sql_get_temp_filename();

	rc = sqlite3_open (filename_temp, &db);
	if (rc != SQLITE_OK)
    {
    	fprintf (stderr, "Can't open database: %s\n", sqlite3_errmsg (db));
    	lp_sql_close_database();
    }
    filename_current = NULL;
}

void
lp_sql_open_database (char *filename)
{
	lp_sql_close_database();

	filename_temp = lp_sql_get_temp_filename();
	lp_copy_file(filename, filename_temp);
	
	int rc = SQLITE_OK;
	rc = sqlite3_open (filename_temp, &db);
	if (rc != SQLITE_OK)
    {
    	fprintf (stderr, "Can't open database: %s\n", sqlite3_errmsg (db));
    	lp_sql_close_database();
    }
    filename_current = g_strdup(filename);
}

int
lp_sql_row_count (char *sql_statement)
{
  //returns the number of rows of a query		
  int rc = SQLITE_OK;
  char *zErrMsg = 0;
  const char *zLeftover;
  row_count = 0;
  col_name = "";
  if (db != NULL)
    {
         //sql_statement = g_strdup ("SELECT * FROM 'class'");
         rc = sqlite3_exec (db, sql_statement, lp_sql_row_callback,
			 0, &zErrMsg);
     
      if (rc != SQLITE_OK)
	{
	  fprintf (stderr, "SQL error: %s\n", zErrMsg);
	  sqlite3_free (zErrMsg);
	}
    }
    printf("row count for '%s'=%d\n", sql_statement, row_count);
    return row_count;
}

char*
lp_sql_value (char *sql_statement, char *column_name)
{
  //returns the last value for a certain column_name		
  int rc = SQLITE_OK;
  char *zErrMsg = 0;
  const char *zLeftover;
  row_count = 0;
  col_name = column_name;
  value_string = g_strdup("");
  if (db != NULL)
    {
         rc = sqlite3_exec (db, sql_statement, lp_sql_row_callback,
			 0, &zErrMsg);
      if (rc != SQLITE_OK)
	{
	  fprintf (stderr, "SQL error: %s\n", zErrMsg);
	  sqlite3_free (zErrMsg);
	}
    }
    printf("value for last row of '%s' = %s\n", sql_statement, value_string);
    return value_string;
}
