/*
 * lpweekly.c
 * lessonplan
 *
 * by Doug Wolfe
 * doug@wolfescience.com 
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 */
 
 /* TODO (#1#): Figure out why the textbuffer does not trigger a 
                changed event after I click on a button (like bold). */
 
 
#include <gtk/gtk.h>
#include <xhtmlite/xhtmlite_module/xhtmlcallbacks.h>
#include <xhtmlite/xhtmlite_module/xhtmlinterface.h>
#include <xhtmlite/xhtmlite_module/xhtmlbuffer.h>

#include "lpdate.h"
#include "lpoptions.h"
#include "lpsql.h"

//for xml
#include <libxml/encoding.h>
#include <libxml/xmlwriter.h>

static int class_count = 0;  //get classes count
static GList * days_list;   //list of days to display

static int show_dates_left = 0;  //default false
static int show_weekly_plans = 1;  //default true
static int show_weekly_plans_at_start = 0;  //default false
static int week_number = 0;
static int year = 0;
static GtkWidget *lp_table_plan;
static GArray *classes;
static GtkWidget *top_window = NULL;
//TODO: Figure out how to store class information or use the database the most efficiently.

/**static void
lp_resize_table ()
{
   if (!show_dates_left)		//setup the days on the top
    {
      gtk_table_resize (GTK_TABLE (lp_table_plan), class_count + 1,
			days_count + 1);
    }
  else				//setup the days on the left
    {
      gtk_table_resize (GTK_TABLE (lp_table_plan), days_count + 1,
			class_count + 1);
    }
}**/


static void 
lp_weekly_dailyplan_on_buffer_changed (GtkTextBuffer *textbuffer, gpointer user_data)
{
	GDate *mydate = g_object_get_data (G_OBJECT(textbuffer), "date");
	gchar *class_id = g_object_get_data (G_OBJECT(textbuffer), "class_id");
	gchar *mydate_string = lp_date_get_sqlite_date_string(mydate);

	gchar *new_text = xhtmlite_write_as_markup(textbuffer);
	gchar *sql_statement;
	sql_statement = g_strdup_printf("SELECT * FROM dailyplan WHERE dailyplan_date='%s' AND class_id='%s'", mydate_string, class_id);
	if(lp_sql_row_count(sql_statement) ==0)
	{
		sql_statement = g_strdup_printf("INSERT INTO dailyplan ('dailyplan_description','dailyplan_date', 'class_id') VALUES ('%s','%s','%s')", new_text, mydate_string, class_id);
	}
	else
	{
		sql_statement = g_strdup_printf("UPDATE dailyplan SET dailyplan_description='%s' WHERE dailyplan_date='%s' AND class_id='%s'", new_text, mydate_string, class_id);
	}
	lp_sql_row_count(sql_statement);
}


static void 
lp_weekly_weeklyplan_on_buffer_changed (GtkTextBuffer *textbuffer, gpointer user_data)
{
	int year_r = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(textbuffer), "year"));
	int week_r = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(textbuffer), "week"));
	gchar *class_id = g_object_get_data (G_OBJECT(textbuffer), "class_id");
	gchar *new_text = xhtmlite_write_as_markup(textbuffer);
	gchar *sql_statement;
      
	sql_statement = g_strdup_printf("SELECT * FROM weeklyplan WHERE weeklyplan_year='%d' AND weeklyplan_week='%d' AND class_id='%s'", year_r, week_r, class_id);
      if(lp_sql_row_count(sql_statement) ==0)
      {
		  sql_statement = g_strdup_printf("INSERT INTO weeklyplan ('weeklyplan_description','weeklyplan_year','weeklyplan_week','class_id') VALUES ('%s','%d','%d','%s')", new_text, year_r, week_r, class_id);
      }
      else
      {
          sql_statement = g_strdup_printf("UPDATE weeklyplan SET weeklyplan_description='%s' WHERE weeklyplan_year='%d' AND weeklyplan_week='%d' AND class_id='%s'", new_text, year_r, week_r, class_id);
      }
      lp_sql_row_count(sql_statement);
}

static void
lp_weekly_day_description_change(GtkWidget *label, const gchar *new_text)
{
	GDate * mydate = g_object_get_data (G_OBJECT(label), "date");
	gchar * mydate_string = lp_date_get_sqlite_date_string(mydate);
	
    gchar *sql_statement;
    sql_statement = g_strdup_printf("SELECT * FROM day WHERE day_date='%s'", mydate_string);
    if(lp_sql_row_count(sql_statement) ==0)
    {
    	sql_statement = g_strdup_printf("INSERT INTO day (`day_description`,`day_date`) VALUES ('%s','%s')", new_text, mydate_string);
    }
    else
    {
        sql_statement = g_strdup_printf("UPDATE day SET day_description='%s' WHERE day_date='%s'", new_text, mydate_string);
    }
    lp_sql_row_count(sql_statement);
    gtk_label_set_markup(GTK_LABEL(label), g_strdup_printf("<span color='blue'>%s</span>",new_text));
}

static void
lp_weekly_day_description_menuitem_activated (GtkMenuItem *menuitem, gpointer user_data)
{
	GtkWidget *menuitem_label = gtk_bin_get_child(GTK_BIN(menuitem)); 
	const gchar *new_text = gtk_label_get_text(GTK_LABEL(menuitem_label));

	GtkWidget *label = user_data;
	lp_weekly_day_description_change(label, new_text);
}

static void
lp_weekly_day_description_edit(GtkWidget *label)
{
	GtkWidget *dialog = create_lp_dialog_value ();
	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(top_window));

	GDate * mydate = g_object_get_data (G_OBJECT(label), "date");
	gchar * mydate_string = lp_date_get_date_string(mydate);
	gtk_window_set_title(GTK_WINDOW(dialog), g_strdup_printf("%s -- Edit Day Description", mydate_string)); 

	GtkWidget *lp_dialog_value_entry = lookup_widget(dialog, "lp_dialog_value_entry");
	gtk_entry_set_text(GTK_ENTRY(lp_dialog_value_entry), gtk_label_get_text(GTK_LABEL(label)));    
	//GtkWidget *lp_dialog_value_label = lookup_widget (widget, "lp_dialog_value_label");      
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
	{
    	gtk_widget_hide(dialog);
    	const gchar *new_text = gtk_entry_get_text(GTK_ENTRY(lp_dialog_value_entry));
		lp_weekly_day_description_change(label, new_text);
	} 
	gtk_widget_destroy(dialog);
}

static void
lp_weekly_day_description_menuitem_edit_activated (GtkMenuItem *menuitem, gpointer user_data)
{
	GtkWidget *label = user_data;
	lp_weekly_day_description_edit(label);
}

static void
lp_weekly_day_description_menuitem_clear_activated (GtkMenuItem *menuitem, GtkWidget *label)
{
	GDate * mydate = g_object_get_data (G_OBJECT(label), "date");
	gchar * mydate_string = lp_date_get_sqlite_date_string(mydate);
	
    gchar *sql_statement;
    sql_statement = g_strdup_printf("SELECT * FROM day WHERE day_date='%s'", mydate_string);
    if(lp_sql_row_count(sql_statement) != 0)
    {
        sql_statement = g_strdup_printf("DELETE FROM day WHERE day_date='%s'", mydate_string);
        lp_sql_row_count(sql_statement);
    }
    gtk_label_set_text(GTK_LABEL(label), g_strdup(""));
}

static void 
lp_weekly_day_description_popup_menu (GdkEventButton *event, GtkWidget *label)
{		
	GtkWidget *menu = gtk_menu_new();

	GtkWidget *item;
	item = gtk_image_menu_item_new_with_label ("Edit Day Description");
	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_SMALL_TOOLBAR));
	g_signal_connect ((gpointer) item, "activate",
               G_CALLBACK (lp_weekly_day_description_menuitem_edit_activated),
               label);
	gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
	
	item = gtk_image_menu_item_new_with_label ("Clear");
	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_SMALL_TOOLBAR));
	g_signal_connect ((gpointer) item, "activate",
               G_CALLBACK (lp_weekly_day_description_menuitem_clear_activated),
               label);
	gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
		
	item = gtk_separator_menu_item_new ();
	gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
		

	gchar *table_name = g_strdup("daylabel");
    gchar *sql_statement = g_strdup_printf("SELECT * FROM %s", table_name);
	int row_count = lp_sql_row_count(sql_statement);
	if (row_count > 0)
	{
		int n;
		for(n=0; n<row_count; n++)
		{
			sql_statement = g_strdup_printf("SELECT * FROM %s LIMIT 1 OFFSET %d", table_name, n);
			gchar *id = lp_sql_value(sql_statement, g_strdup_printf("%s_id", table_name));
			gchar *name = lp_sql_value(sql_statement, g_strdup_printf("%s_name", table_name));			

			item = gtk_image_menu_item_new_with_label (name);
			g_signal_connect ((gpointer) item, "activate",
                G_CALLBACK (lp_weekly_day_description_menuitem_activated),
                 label);
			gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);	
		}
	}

	gtk_widget_show_all(menu);
	gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL, event->button, 0);
	menu = NULL;
}


static gboolean   
lp_weekly_day_description_button_release_event (GtkWidget *widget,
                          GdkEventButton *event,
                          gpointer        user_data)
{
	GtkWidget *label = xhtmlite_widget_find_child_by_name (widget, "label_day_description");
	if (event->button == 3)
	{
		lp_weekly_day_description_popup_menu (event, label);
	}
	else
	{
		lp_weekly_day_description_edit(label);
	}
}


static void
lp_weekly_week_description_change(GtkWidget *label, const gchar *new_text)
{
	int year_r = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(label), "year"));
	int week_r = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(label), "week"));
	
	gchar *sql_statement = g_strdup_printf("SELECT * FROM week WHERE week_year='%d' AND week_week='%d'", year_r, week_r);
    if(lp_sql_row_count(sql_statement) ==0)
    {
    	sql_statement = g_strdup_printf("INSERT INTO week (`week_description`,`week_year`,`week_week`) VALUES ('%s','%d','%d')", new_text, year_r, week_r);
    }
    else
    {
        sql_statement = g_strdup_printf("UPDATE week SET week_description='%s' WHERE week_year='%d' AND week_week='%d'", new_text, year_r, week_r);
    }
    lp_sql_row_count(sql_statement);
    gtk_label_set_markup(GTK_LABEL(label), g_strdup_printf("<span color='blue'>%s</span>",new_text));
}

static void
lp_weekly_week_description_menuitem_activated (GtkMenuItem *menuitem, gpointer user_data)
{
	GtkWidget *menuitem_label = gtk_bin_get_child(GTK_BIN(menuitem));  
	gchar *new_text = gtk_label_get_text(GTK_LABEL(menuitem_label));

	GtkWidget *label = user_data;
	lp_weekly_week_description_change(label, new_text);
}

static void
lp_weekly_week_description_edit(GtkWidget *label)
{
	GtkWidget *dialog = create_lp_dialog_value ();
	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(top_window));

	GDate * mydate = g_object_get_data (G_OBJECT(label), "date");
	gchar * mydate_string = lp_date_get_date_string(mydate);
	gtk_window_set_title(GTK_WINDOW(dialog), g_strdup_printf("%s -- Edit Day Description", mydate_string)); 

	GtkWidget *lp_dialog_value_entry = lookup_widget (dialog, "lp_dialog_value_entry");
	gtk_entry_set_text(GTK_ENTRY(lp_dialog_value_entry), gtk_label_get_text(GTK_LABEL(label)));    
	//GtkWidget *lp_dialog_value_label = lookup_widget (widget, "lp_dialog_value_label");      
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
	{
    	gtk_widget_hide(dialog);
    	const gchar * new_text = gtk_entry_get_text(GTK_ENTRY(lp_dialog_value_entry));
		lp_weekly_week_description_change(label, new_text);
	} 
	gtk_widget_destroy(dialog);
}

static void
lp_weekly_week_description_menuitem_edit_activated (GtkMenuItem *menuitem, gpointer user_data)
{
	GtkWidget *label = user_data;
	lp_weekly_week_description_edit(label);
}

static void
lp_weekly_week_description_menuitem_clear_activated (GtkMenuItem *menuitem, GtkWidget *label)
{
	int year_r = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(label), "year"));
	int week_r = GPOINTER_TO_INT(g_object_get_data (G_OBJECT(label), "week"));
	
    gchar *sql_statement;
    sql_statement = g_strdup_printf("SELECT * FROM week WHERE week_year='%d' AND week_week='%d'", year_r, week_r);
    if(lp_sql_row_count(sql_statement) != 0)
    {
        sql_statement = g_strdup_printf("DELETE FROM week WHERE week_year='%d' AND week_week='%d'", year_r, week_r);
    	lp_sql_row_count(sql_statement);
    }
    gtk_label_set_text(GTK_LABEL(label), g_strdup(""));
}

static void 
lp_weekly_week_description_popup_menu (GdkEventButton *event, GtkWidget *label)
{		
	GtkWidget *menu = gtk_menu_new();

	GtkWidget *item;
	item = gtk_image_menu_item_new_with_label ("Edit Week Description");
	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), gtk_image_new_from_stock (GTK_STOCK_EDIT, GTK_ICON_SIZE_SMALL_TOOLBAR));
	g_signal_connect ((gpointer) item, "activate",
               G_CALLBACK (lp_weekly_week_description_menuitem_edit_activated),
               label);
	gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
	
	item = gtk_image_menu_item_new_with_label ("Clear");
	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(item), gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_SMALL_TOOLBAR));
	g_signal_connect ((gpointer) item, "activate",
               G_CALLBACK (lp_weekly_week_description_menuitem_clear_activated),
               label);
	gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
		
	item = gtk_separator_menu_item_new ();
	gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);
		

	gchar *table_name = g_strdup("weeklabel");
    gchar *sql_statement = g_strdup_printf("SELECT * FROM %s", table_name);
	int row_count = lp_sql_row_count(sql_statement);
	if (row_count > 0)
	{
		int n;
		for(n=0; n<row_count; n++)
		{
			sql_statement = g_strdup_printf("SELECT * FROM %s LIMIT 1 OFFSET %d", table_name, n);
			gchar *id = lp_sql_value(sql_statement, g_strdup_printf("%s_id", table_name));
			gchar *name = lp_sql_value(sql_statement, g_strdup_printf("%s_name", table_name));			

			item = gtk_image_menu_item_new_with_label (name);
			g_signal_connect ((gpointer) item, "activate",
                G_CALLBACK (lp_weekly_week_description_menuitem_activated),
                 label);
			gtk_menu_shell_append (GTK_MENU_SHELL(menu), item);	
		}
	}

	gtk_widget_show_all(menu);
	gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL, event->button, 0);
	menu = NULL;
}


static gboolean   
lp_weekly_week_description_button_release_event (GtkWidget *widget,
                          GdkEventButton *event,
                          gpointer        user_data)
{
	GtkWidget *label = xhtmlite_widget_find_child_by_name (widget, "label_week_description");
	if (event->button == 3)
	{
		lp_weekly_week_description_popup_menu (event, label);
	}
	else
	{
		lp_weekly_week_description_edit(label);
	}
}


static gboolean   
lp_weekly_class_name_button_release_event (GtkWidget *widget,
                          GdkEventButton *event,
                          gpointer        user_data)
{
	GtkWidget *dialog = create_lp_dialog_value ();
	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(top_window));
	
	GtkWidget *label =  xhtmlite_widget_find_child_by_name (widget, "label_class_name");
	gchar *class_id =  g_object_get_data(G_OBJECT(widget), "class_id");
	
	gtk_window_set_title(GTK_WINDOW(dialog), g_strdup_printf("%s -- Edit Class Name", label)); 
	
	GtkWidget *lp_dialog_value_entry = lookup_widget (dialog, "lp_dialog_value_entry");
	gtk_entry_set_text(GTK_ENTRY(lp_dialog_value_entry), gtk_label_get_text(GTK_LABEL(label)));    
	//GtkWidget *lp_dialog_value_label = lookup_widget (widget, "lp_dialog_value_label");      
	if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
	{
		gtk_widget_hide(dialog);
		gchar * new_text = gtk_entry_get_text(GTK_ENTRY(lp_dialog_value_entry));
		gtk_label_set_text(GTK_LABEL(label), new_text);
		gtk_label_set_markup(GTK_LABEL(label), g_strdup_printf("<b>%s</b>",new_text));
		
		gchar *sql_statement;
		sql_statement = g_strdup_printf("SELECT * FROM class WHERE class_id='%s'", class_id);
		sql_statement = g_strdup_printf("UPDATE class SET class_name='%s' WHERE class_id='%s'", new_text, class_id);
		lp_sql_row_count(sql_statement);
	} 
	gtk_widget_destroy(dialog);
}

static int
lp_weekly_class_visible(gchar *class_id)
{
	GList *get_date = g_list_first(days_list);  
	GDate *visible_startdate = g_list_nth_data(get_date, 0);
	get_date = g_list_last(days_list);  
	GDate *visible_enddate = g_list_nth_data(get_date, 0);  
	//test to make sure the class is set between these days
	gchar *sql_statement = g_strdup_printf("SELECT * FROM class WHERE class_id=%s", class_id);
	gchar *column_name = g_strdup("class_startdate");
	gchar *test_date = lp_sql_value(sql_statement, column_name);
	GDate *startdate = lp_date_get_date_from_sqlite_format(test_date);
	if(g_date_compare(visible_enddate, startdate)>=0)
	{
		g_date_free(startdate);
		column_name = g_strdup("class_enddate");
		test_date = lp_sql_value(sql_statement, column_name);
		GDate *enddate = lp_date_get_date_from_sqlite_format(test_date);
		if(g_date_compare(visible_startdate, enddate)<=0)
		{
			g_date_free(enddate);
			g_free(sql_statement);
			g_free(column_name);
			g_free(test_date);
			return 1;
		}
		g_date_free(enddate);
	}
	else
	{
		g_date_free(startdate);
	}
	g_free(sql_statement);
	g_free(column_name);
	g_free(test_date);
	return 0;
}

static int
lp_weekly_class_date_visible(gchar *class_id, GDate *mydate)
{
printf("%s\n", lp_date_get_sqlite_date_string(mydate));

	//test to make sure the class is set between these days
	gchar *sql_statement = g_strdup_printf("SELECT * FROM class WHERE class_id=%s", class_id);
	gchar *column_name = g_strdup("class_startdate");
	gchar *test_date = lp_sql_value(sql_statement, column_name);
	GDate *startdate = lp_date_get_date_from_sqlite_format(test_date);
	printf("startdate:%s\n", lp_date_get_sqlite_date_string(startdate));
	if(g_date_compare(mydate, startdate)>=0)
	{
		g_date_free(startdate);
		column_name = g_strdup("class_enddate");
		test_date = lp_sql_value(sql_statement, column_name);
		GDate *enddate = lp_date_get_date_from_sqlite_format(test_date);
		printf("enddate:%s\n", lp_date_get_sqlite_date_string(enddate));
		if(g_date_compare(mydate, enddate)<=0)
		{
			g_date_free(enddate);
			g_free(sql_statement);
			g_free(column_name);
			g_free(test_date);
			printf("****************date is valid\n\n");
			return 1;
		}
		g_date_free(enddate);
	}
	else
	{
		g_date_free(startdate);
	}
	g_free(sql_statement);
	g_free(column_name);
	g_free(test_date);
	printf("^^^^^^^^^^^^^^^^^^^^^^^^^^^date is NOT NOT NOT valid\n\n");
	return 0;
}

static void
lp_weekly_insert_weekly_plan(int colrow)
{
		gchar *column_name;
		gchar *description;
		gchar *sql_statement;
		
		GtkWidget *eventbox = gtk_event_box_new ();
		gtk_widget_set_name (eventbox, "lp_weekly_event_box");
		g_signal_connect ((gpointer) eventbox, "button-release-event",
                    G_CALLBACK (lp_weekly_week_description_button_release_event),
                    NULL);
		GtkWidget *box;
		GtkWidget *label_week_number = gtk_label_new ("");
		gtk_widget_set_name(label_week_number, "label_week_number");
		gtk_label_set_markup(GTK_LABEL(label_week_number), g_strdup_printf("<b>Week #%d</b>", week_number));
		GtkWidget *label_year = gtk_label_new (g_strdup_printf("%d", year));
		gtk_widget_set_name(label_year, "label_year");

		sql_statement = g_strdup_printf("SELECT * FROM week WHERE week_year='%d' AND week_week='%d'", year, week_number);
		column_name = g_strdup("week_description");
		description = g_strdup(lp_sql_value(sql_statement, column_name));
		GtkWidget *label_description = gtk_label_new (description);
		gtk_label_set_markup (GTK_LABEL(label_description), g_strdup_printf("<span color='blue'>%s</span>", description));
		gtk_label_set_width_chars(GTK_LABEL(label_description), 20);
		gtk_widget_set_name(label_description, "label_week_description");
		g_object_set_data (G_OBJECT(label_description), "year", GINT_TO_POINTER(year));
		g_object_set_data (G_OBJECT(label_description), "week", GINT_TO_POINTER(week_number));

		if (!show_dates_left)
		{
			box = gtk_vbox_new (TRUE, 1);
			gtk_table_attach (GTK_TABLE (lp_table_plan),
			    eventbox,
			    colrow + 1, colrow + 2,
			    0, 1, GTK_EXPAND || GTK_FILL, GTK_SHRINK, 1, 1);
		}
		else
		{
			box = gtk_hbox_new (TRUE, 1);
			gtk_label_set_angle (GTK_LABEL (label_week_number), 90);
			gtk_label_set_angle (GTK_LABEL (label_year), 90);
			gtk_label_set_angle (GTK_LABEL (label_description), 90);
			gtk_widget_set_size_request(label_description,-1,100);
			gtk_table_attach (GTK_TABLE (lp_table_plan),
			    eventbox,
			    0, 1,
			    colrow + 1, colrow + 2,
			    GTK_SHRINK, GTK_EXPAND || GTK_FILL, 1, 1);
		}

		gtk_container_add (GTK_CONTAINER (eventbox), box);
		gtk_box_pack_start (GTK_BOX (box), label_week_number, TRUE, TRUE, 0);
		gtk_box_pack_start (GTK_BOX (box), label_year, TRUE, TRUE, 0);
		gtk_box_pack_start (GTK_BOX (box), label_description, TRUE, TRUE, 0);
		gtk_widget_show_all (eventbox);
}

static void
lp_weekly_setup_days()
{
    //setup dates
	int d = 0;
	int colrow = 0;
	gchar *mydate_string;
	gchar myday_of_week[101];
	gchar *column_name;
	gchar *day_description;
	gchar *sql_statement;

	if(show_weekly_plans)
	{
		if(show_weekly_plans_at_start)
		{
			lp_weekly_insert_weekly_plan(colrow);	
			colrow += 1;
		}
	}

	while (d <  g_list_length (days_list))
    {
		GDate *setdate = g_list_nth_data(days_list,d);  
		mydate_string = lp_date_get_sqlite_date_string(setdate);
		g_date_strftime (myday_of_week, 100, "%A\0", setdate);
		printf ("current date:%s\n", mydate_string);
		GtkWidget *eventbox_day = gtk_event_box_new ();
		gtk_widget_set_name (eventbox_day, "lp_day_event_box");
		g_signal_connect ((gpointer) eventbox_day, "button-release-event",
                    G_CALLBACK (lp_weekly_day_description_button_release_event),
                    NULL);
		GtkWidget *box_day;
		GtkWidget *label_day_of_week = gtk_label_new (myday_of_week);
		gtk_widget_set_name(label_day_of_week, "label_day_of_week");
		gtk_label_set_markup(GTK_LABEL(label_day_of_week), g_strdup_printf("<b>%s</b>",myday_of_week));
		GtkWidget *label_day = gtk_label_new (lp_date_get_date_string(setdate));
		gtk_widget_set_name(label_day, "label_day_date");

		sql_statement = g_strdup_printf("SELECT * FROM day WHERE day_date='%s'", mydate_string);
		column_name = g_strdup("day_description");
		day_description = g_strdup(lp_sql_value(sql_statement, column_name));
		GtkWidget *label_day_description = gtk_label_new (day_description);
		gtk_label_set_markup (GTK_LABEL(label_day_description), g_strdup_printf("<span color='blue'>%s</span>", day_description));
		gtk_label_set_width_chars(GTK_LABEL(label_day_description), 20);
		gtk_widget_set_name(label_day_description, "label_day_description");
		GDate * savedate = g_date_new_dmy (g_date_get_day (setdate),
				   g_date_get_month (setdate),
				   g_date_get_year (setdate));
		g_object_set_data (G_OBJECT(label_day_description), "date", savedate);

		if (!show_dates_left)
		{
			box_day = gtk_vbox_new (TRUE, 1);
			gtk_table_attach (GTK_TABLE (lp_table_plan),
			    eventbox_day,
			    colrow + 1, colrow + 2,
			    0, 1, GTK_EXPAND || GTK_FILL, GTK_SHRINK, 1, 1);
		}
		else
		{
			box_day = gtk_hbox_new (TRUE, 1);
			gtk_label_set_angle (GTK_LABEL (label_day_of_week), 90);
			gtk_label_set_angle (GTK_LABEL (label_day), 90);
			gtk_label_set_angle (GTK_LABEL (label_day_description), 90);
			gtk_widget_set_size_request(label_day_description,-1,100);
			gtk_table_attach (GTK_TABLE (lp_table_plan),
			    eventbox_day,
			    0, 1,
			    colrow + 1, colrow + 2,
			    GTK_SHRINK, GTK_EXPAND || GTK_FILL, 1, 1);
		}

		gtk_container_add (GTK_CONTAINER (eventbox_day), box_day);
		gtk_box_pack_start (GTK_BOX (box_day), label_day_of_week, TRUE, TRUE, 0);
		gtk_box_pack_start (GTK_BOX (box_day), label_day, TRUE, TRUE, 0);
		gtk_box_pack_start (GTK_BOX (box_day), label_day_description, TRUE, TRUE, 0);
		gtk_widget_show_all (eventbox_day);
		d += 1;
		colrow +=1;
	}         
	
	if(show_weekly_plans)
	{
		if(!show_weekly_plans_at_start)
		{
			lp_weekly_insert_weekly_plan(colrow);	
		}
	}       
}

static void
lp_weekly_setup_classes()
{
	//setup class names
  int c = 0;
  gchar * class_name;
  gchar * column_name;
  gchar *  class_id;
  gchar *sql_statement = g_strdup ("SELECT * FROM 'class'");
  class_count = lp_sql_row_count(sql_statement); //Reset class count
  while (c < class_count)
    {
		sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", c); 

		column_name = g_strdup("class_id"); 
		class_id = g_strdup(lp_sql_value(sql_statement, column_name));
		
		if(lp_weekly_class_visible(class_id))
		{
			GtkWidget *eventbox_class = gtk_event_box_new ();
			gtk_widget_set_name (eventbox_class, "lp_class_event_box");
			g_signal_connect ((gpointer) eventbox_class, "button-release-event",
                    G_CALLBACK (lp_weekly_class_name_button_release_event),
                    NULL);
			GtkWidget *box_class;
      
			column_name = g_strdup("class_name"); 
			class_name = g_strdup(lp_sql_value(sql_statement, column_name));
			GtkWidget *label_class_name = gtk_label_new (class_name);
			gtk_label_set_markup(GTK_LABEL(label_class_name), g_strdup_printf("<b>%s</b>",class_name));
			gtk_label_set_width_chars(GTK_LABEL(label_class_name), 20);
			gtk_widget_set_name(label_class_name, "label_class_name");
			
			g_object_set_data(G_OBJECT(eventbox_class), "class_id", class_id);
			
			if (!show_dates_left)
			{
				box_class = gtk_hbox_new (TRUE, 1);
				gtk_label_set_angle (GTK_LABEL (label_class_name), 90);
				gtk_widget_set_size_request(label_class_name,-1,100);
				gtk_table_attach (GTK_TABLE (lp_table_plan),
					    eventbox_class,
					    0, 1,
					    c + 1, c + 2,
					    GTK_SHRINK, GTK_EXPAND || GTK_FILL, 1, 1);
			}
			else
			{
				box_class = gtk_vbox_new (TRUE, 1);
				gtk_table_attach (GTK_TABLE (lp_table_plan),
					    eventbox_class,
					    c + 1, c + 2,
					    0, 1, GTK_EXPAND || GTK_FILL, GTK_SHRINK, 1, 1);
			}
			
			gtk_container_add (GTK_CONTAINER (eventbox_class), box_class);
			gtk_box_pack_start (GTK_BOX (box_class), label_class_name, TRUE, TRUE, 0);
			gtk_widget_show_all (eventbox_class);
		}
		c += 1;
	}
}

static gboolean 
lp_weekly_textview_weeklyplan_focus_in_event (GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
{
	GtkTextBuffer *textbuffer =	gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
	lp_weekly_weeklyplan_on_buffer_changed(textbuffer, NULL);
	return FALSE;
}

static gboolean 
lp_weekly_textview_weeklyplan_focus_out_event (GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
{
	GtkTextBuffer *textbuffer =	gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
	lp_weekly_weeklyplan_on_buffer_changed(textbuffer, NULL);
	return FALSE;
}

static void
lp_weekly_insert_weeklyplan(int c, int r)
{
	GtkWidget *textview = gtk_text_view_new ();
	gtk_widget_set_name(textview, "xhtmlite_textview");
	gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
	GtkTextBuffer *textbuffer = xhtmlite_create_buffer (GTK_TEXT_VIEW(textview), TRUE);
	xhtmlite_attach_textview_events(textview);
    
	gchar *sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", c); 
	gchar *column_name = g_strdup("class_id"); 
	gchar *class_id = g_strdup(lp_sql_value(sql_statement, column_name));
    if(lp_weekly_class_visible(class_id))
	{ 
		sql_statement = g_strdup_printf("SELECT * FROM weeklyplan WHERE class_id=%s AND weeklyplan_year='%d' AND weeklyplan_week='%d'", class_id, year, week_number);
		column_name = g_strdup("weeklyplan_description");
		gchar *plan_description = g_strdup_printf("%s", lp_sql_value(sql_statement, column_name));
	      
		xhtmlite_import (textbuffer, plan_description, TRUE);
		g_object_set_data (G_OBJECT(textbuffer), "year", GINT_TO_POINTER(year));
		g_object_set_data (G_OBJECT(textbuffer), "week", GINT_TO_POINTER(week_number));
		g_object_set_data (G_OBJECT(textbuffer), "class_id", class_id);
		
		g_signal_connect ((gpointer) textview, "focus_in_event", 	     
				G_CALLBACK (lp_weekly_textview_weeklyplan_focus_in_event), NULL);
		g_signal_connect ((gpointer) textview, "focus_out_event", 		     
				G_CALLBACK (lp_weekly_textview_weeklyplan_focus_out_event), NULL);
		  
		GtkWidget *scrolled_window = gtk_scrolled_window_new (NULL, NULL);
		gtk_widget_set_name(scrolled_window, "lp_scrolled_window");
		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW
						  (scrolled_window),
						  GTK_POLICY_AUTOMATIC,
						  GTK_POLICY_AUTOMATIC);
		gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW
							 (scrolled_window),
							 GTK_WIDGET (textview));
	
		if (!show_dates_left)
		{
			gtk_table_attach_defaults (GTK_TABLE (lp_table_plan),
						 GTK_WIDGET (scrolled_window),
						 r + 1, r + 2, c + 1, c + 2);
		}
		else
		{
			gtk_table_attach_defaults (GTK_TABLE (lp_table_plan),
						 GTK_WIDGET (scrolled_window),
						 c + 1, c + 2, r + 1, r + 2);
		}
		gtk_widget_show_all (GTK_WIDGET (scrolled_window));	
	}
}

static gboolean 
lp_weekly_textview_dailyplan_focus_in_event (GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
{
	GtkTextBuffer *textbuffer =	gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
	lp_weekly_dailyplan_on_buffer_changed(textbuffer, NULL);
	return FALSE;
}

static gboolean 
lp_weekly_textview_dailyplan_focus_out_event (GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
{
	GtkTextBuffer *textbuffer =	gtk_text_view_get_buffer(GTK_TEXT_VIEW(widget));
	lp_weekly_dailyplan_on_buffer_changed(textbuffer, NULL);
	return FALSE;
}

static void
lp_weekly_setup_dailyplans()
{
	//add day plans
	int c = 0;
	int r = 0;
	int d = 0;
	gchar *plan_description;
	gchar *test_date;
	gchar *column_name;
	gchar *class_id;
	while (c < class_count)
    {
		d = 0;
		r = 0;
		if(show_weekly_plans)
		{
			if(show_weekly_plans_at_start)
			{
				lp_weekly_insert_weeklyplan(c, r);	
				r += 1;
			}
		}
		while (d <  g_list_length (days_list))
		{
			GDate *setdate = g_list_nth_data(days_list,d);  
			GtkWidget *textview = gtk_text_view_new ();
			gtk_widget_set_name(textview, "xhtmlite_textview");
			gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW(textview), GTK_WRAP_WORD);
			GtkTextBuffer *textbuffer = xhtmlite_create_buffer (GTK_TEXT_VIEW(textview), TRUE);
			xhtmlite_attach_textview_events(textview);
			
			gchar *sql_statement = g_strdup_printf("SELECT * FROM class LIMIT 1 OFFSET %d", c); 
			column_name = g_strdup("class_id"); 
			class_id = g_strdup(lp_sql_value(sql_statement, column_name));

			//test to make sure the class is set between these days
			if(lp_weekly_class_visible(class_id))
			{
				if(lp_weekly_class_date_visible(class_id, setdate))
				{		
					//build the dayplan
					gchar *mydate_string = lp_date_get_sqlite_date_string(setdate);
					sql_statement = g_strdup_printf("SELECT * FROM dailyplan WHERE class_id=%s AND dailyplan_date='%s'", class_id, mydate_string);
					column_name = g_strdup("dailyplan_description");
					plan_description = lp_sql_value(sql_statement, column_name);
					
					xhtmlite_import (textbuffer, plan_description, TRUE);
					GDate *savedate = g_date_new_dmy (g_date_get_day (setdate),
						   g_date_get_month (setdate),
						   g_date_get_year (setdate));
					g_object_set_data (G_OBJECT(textbuffer), "date", savedate);
					g_object_set_data (G_OBJECT(textbuffer), "class_id", class_id);
					//g_signal_connect ((gpointer) textbuffer, "changed",
					//			G_CALLBACK (lp_weekly_on_dailyplan_buffer_changed),
					//			NULL);
					
					g_signal_connect ((gpointer) textview, "focus_in_event", 	     
					G_CALLBACK (lp_weekly_textview_dailyplan_focus_in_event), NULL);
					g_signal_connect ((gpointer) textview, "focus_out_event", 		     
					G_CALLBACK (lp_weekly_textview_dailyplan_focus_out_event), NULL);
					
					GtkWidget *scrolled_window = gtk_scrolled_window_new (NULL, NULL);
					gtk_widget_set_name(scrolled_window, "lp_scrolled_window");
					gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW
							  (scrolled_window),
							  GTK_POLICY_AUTOMATIC,
							  GTK_POLICY_AUTOMATIC);
					gtk_scrolled_window_add_with_viewport (GTK_SCROLLED_WINDOW
								 (scrolled_window),
								 GTK_WIDGET (textview));
					
					if (!show_dates_left)
					{
						gtk_table_attach_defaults (GTK_TABLE (lp_table_plan),
							 GTK_WIDGET (scrolled_window),
							 r + 1, r + 2, c + 1, c + 2);
					}
					else
					{
						gtk_table_attach_defaults (GTK_TABLE (lp_table_plan),
							 GTK_WIDGET (scrolled_window),
							 c + 1, c + 2, r + 1, r + 2);
					}
					gtk_widget_show_all (GTK_WIDGET (scrolled_window));	
				}
				r += 1;				
			}
			d += 1;
		}
		if(show_weekly_plans)
		{
			if(!show_weekly_plans_at_start)
			{
				lp_weekly_insert_weeklyplan(c, r);	
			}
		}
		c += 1;
    }
}

static void
lp_weekly_get_options(GtkWidget *lp_window_main, GDate *date)
{
	/* TODO (#1#): Fix month option */
	
    //defaults
	GtkWidget *lp_main_label_date = lookup_widget (lp_window_main, "lp_main_label_date");
	if(date == NULL)
	{
		date =	g_object_get_data (G_OBJECT(lp_main_label_date), "date");
	}

    int show_month = lp_options_show_month(-1); 
    int show_weekday_first = lp_options_get_weekday_first(-1);
    int hide_monday = lp_options_hide_monday(-1);
    int hide_tuesday = lp_options_hide_tuesday(-1);
    int hide_wednesday = lp_options_hide_wednesday(-1);
    int hide_thursday = lp_options_hide_thursday(-1);
    int hide_friday = lp_options_hide_friday(-1);
    int hide_saturday = lp_options_hide_saturday(-1);
    int hide_sunday = lp_options_hide_sunday(-1);
    
    show_dates_left = lp_options_get_show_dates_left(-1);
	show_weekly_plans = lp_options_show_weekly_plan(-1);  //default true
	show_weekly_plans_at_start = lp_options_show_weekly_at_start(-1);  //default false
         
    GDate *setdate = g_date_new_dmy (g_date_get_day (date),
				   g_date_get_month (date),
				   g_date_get_year (date));

    int days_count = 0;
     if (show_month)
    {
      g_date_set_day(setdate,1);
      days_count = g_date_get_days_in_month(g_date_get_month(setdate), g_date_get_year(setdate));
    }
    else
    {
     lp_date_get_first_of_week(setdate, show_weekday_first);
        days_count = 7;
    }
 
    week_number = lp_date_get_week_of_year(setdate, show_weekday_first);
    year = setdate->year;
	printf("week number:%d, year:%d\n", week_number, year);
    
    /*store the date on the date label*/
    GDate * store_date = g_date_new_dmy (g_date_get_day (setdate),g_date_get_month (setdate), g_date_get_year (setdate)); 
    gchar date_string[101];
	g_date_strftime (date_string, 100, "%Y/%m/%d\0", store_date);
	gtk_label_set_text (GTK_LABEL (lp_main_label_date), date_string);
	g_object_set_data (G_OBJECT(lp_main_label_date), "date", store_date);
	printf("setdate: %d/%d/%d\n\n", g_date_get_year(store_date), g_date_get_month(store_date), g_date_get_day(store_date));	
	/**/
    
    /*Add all the possible dates*/
    int d = 0;
   while (d <  g_list_length (days_list))
   {
       days_list = g_list_remove (days_list, g_list_nth_data(days_list,0));
   }
    while(d < days_count)
    {   
      printf("d=%d\n", d);
       GDateWeekday day_of_week2 = g_date_get_weekday (setdate);
       if(day_of_week2 == G_DATE_MONDAY && hide_monday)
       {/**If hide_saturday=TRUE, ignore Saturday**/}
       else if(day_of_week2 == G_DATE_TUESDAY && hide_tuesday)
       {/**If hide_saturday=TRUE, ignore Saturday**/}
       else if(day_of_week2 == G_DATE_WEDNESDAY && hide_wednesday)
       {/**If hide_saturday=TRUE, ignore Saturday**/}
       else if(day_of_week2 == G_DATE_THURSDAY && hide_thursday)
       {/**If hide_saturday=TRUE, ignore Saturday**/}
       else if(day_of_week2 == G_DATE_FRIDAY && hide_friday)
       {/**If hide_saturday=TRUE, ignore Saturday**/}
       else if(day_of_week2 == G_DATE_SATURDAY && hide_saturday)
       {/**If hide_saturday=TRUE, ignore Saturday**/}
       else if(day_of_week2 == G_DATE_SUNDAY && hide_sunday)
       {/**If hide_sunday=TRUE, ignore Sunday**/}              
        else
        {
	       GDate *save_date = g_date_new_dmy (g_date_get_day (setdate),
				   g_date_get_month (setdate),
				   g_date_get_year (setdate)); 
			//g_object_set_data(G_OBJECT(save_date), "day", 1);/GDate is not G_OBJECT
            days_list = g_list_append (days_list, save_date); 
        }
        g_date_add_days (setdate, 1);
         d+=1;
    }      
}

void
lp_weekly_setup (GtkWidget *lp_window_main, GDate *date)
{
	top_window = lp_window_main;
	lp_table_plan = lookup_widget (lp_window_main, "lp_table_plan");

	//rebuild table
	//first destroy all the widgets in the table
	gtk_container_foreach (GTK_CONTAINER (lp_table_plan),
			 (GtkCallback) gtk_widget_destroy, NULL); 
	//second set the table to the minimum size.   The table auto-grows.
	gtk_table_resize (GTK_TABLE (lp_table_plan), 1, 1); 
  
	lp_weekly_get_options(lp_window_main, date);

	lp_weekly_setup_days();
	lp_weekly_setup_classes();  //needs to be run before setting up daily plans
	lp_weekly_setup_dailyplans();
	
	xhtmlite_track_tags(lp_window_main);
}

#define MY_ENCODING "UTF-8"
void
lp_export_to_html(GtkWidget *widget, const char *uri)
{
	/* TODO (#1#): Finish this function using the same sort of 
	               sub-funtions as used to build the lp_table_plan. */
	
	GtkTable *lp_table_plan = GTK_TABLE(lookup_widget (widget, "lp_table_plan"));
    int rc;
    xmlTextWriterPtr writer;
    xmlChar *tmp;

    /* Create a new XmlWriter for uri, with no compression. */
    writer = xmlNewTextWriterFilename(uri, 0);
    if (writer == NULL) {
        printf("testXmlwriterFilename: Error creating the xml writer\n");
        return;
    }

    /* Start the document with the xml default for the version,
     * encoding ISO 8859-1 and the default for the standalone
     * declaration. */
     printf("write start document element\n");
    rc = xmlTextWriterStartDocument(writer, NULL, MY_ENCODING, NULL);
    if (rc < 0) {
        printf
            ("testXmlwriterFilename: Error at xmlTextWriterStartDocument\n");
        return;
    }

	/* Start an element named "HTML". Since thist is the first
	* element, this will be the root element of the document. */
	printf("write start 'html' element\n");
	rc = xmlTextWriterStartElement(writer, BAD_CAST "html");
	if (rc < 0) {
		printf("testXmlwriterFilename: Error at xmlTextWriterStartElement\n");
		return;
	}	
	
	printf("write start 'body' element\n");
	rc = xmlTextWriterStartElement(writer, BAD_CAST "body");
	if (rc < 0) {
		printf("testXmlwriterFilename: Error at xmlTextWriterStartElement\n");
		return;
	}

	printf("write start 'table' element\n");
	rc = xmlTextWriterStartElement(writer, BAD_CAST "table");
	if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterStartElement\n");return;}	

	/*Get table children*/
	GList *children = lp_table_plan->children;
	int child = 0;
	int child_length = g_list_length (children);
	int r;
	for (r = 0; r < lp_table_plan->nrows;r++)
	{
		/* Start the element named 'tr'. */
			rc = xmlTextWriterWriteString(writer, BAD_CAST "\n");
		printf("write start 'tr' element\n");
		rc = xmlTextWriterStartElement(writer, BAD_CAST "tr");
		if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterStartElement\n");return;}
	

		int c;
		for (c = 0; c < lp_table_plan->ncols;c++)
		{
			/* Start the element named 'td'. */
				rc = xmlTextWriterWriteString(writer, BAD_CAST "\n  ");
			printf("write start 'td' element\n");
			rc = xmlTextWriterStartElement(writer, BAD_CAST "td");
			if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterStartElement\n");return;}
		
			for(child=0; child<child_length; child++)
			{
				/*get column info*/
				GtkTableChild *tablechild = g_list_nth_data(children, child);
				printf(" tablechild->left_attach, tablechild->top_attach:(%d,%d) c,r:(%d,%d)\n", tablechild->left_attach, tablechild->top_attach, c, r); 
				if (tablechild->left_attach == c && tablechild->top_attach == r)
				{
					printf("**Enter\n");
					GtkWidget *box = tablechild->widget;
					if(xhtmlite_widget_find_child_by_name (box, "lp_day_event_box") != NULL)
					{
						GtkWidget *label_day_of_week = xhtmlite_widget_find_child_by_name (box, "label_day_of_week");
						GtkWidget *label_day_date = xhtmlite_widget_find_child_by_name (box, "label_day_date");
						GtkWidget *label_day_description = xhtmlite_widget_find_child_by_name (box, "label_day_description");
						if(label_day_date != NULL)
						{
							rc = xmlTextWriterWriteFormatRaw(writer, "<div align='center'><b>%s</b><br />\n%s<br />\n<span style='color:blue'>%s</span></div>", 
								BAD_CAST gtk_label_get_text(GTK_LABEL(label_day_of_week)),
								BAD_CAST gtk_label_get_text(GTK_LABEL(label_day_date)),
								BAD_CAST gtk_label_get_text(GTK_LABEL(label_day_description)));
							if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterWriteString\n");return;}	
						}
					}
					if(xhtmlite_widget_find_child_by_name (box, "lp_weekly_event_box") != NULL)
					{
						GtkWidget *label_week_number = xhtmlite_widget_find_child_by_name (box, "label_week_number");
						GtkWidget *label_year = xhtmlite_widget_find_child_by_name (box, "label_year");
						GtkWidget *label_week_description = xhtmlite_widget_find_child_by_name (box, "label_week_description");
						if(label_year != NULL)
						{
							rc = xmlTextWriterWriteFormatRaw(writer, "<div align='center'><b>%s</b><br />\n%s<br />\n<span style='color:blue'>%s</span></div>", 
								BAD_CAST gtk_label_get_text(GTK_LABEL(label_week_number)),
								BAD_CAST gtk_label_get_text(GTK_LABEL(label_year)),
								BAD_CAST gtk_label_get_text(GTK_LABEL(label_week_description)));
							if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterWriteString\n");return;}	
						}
					}
					if(xhtmlite_widget_find_child_by_name (box, "lp_class_event_box") != NULL)
					{
						GtkWidget *label_class_name = xhtmlite_widget_find_child_by_name (box, "label_class_name");
						gchar *text = gtk_label_get_text(GTK_LABEL(label_class_name));
						rc = xmlTextWriterWriteFormatRaw(writer, "<b>%s</b>", BAD_CAST text);
						if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterWriteString\n");return;}	
					}
					if(xhtmlite_widget_find_child_by_name (box, "lp_scrolled_window") != NULL)
					{
						GtkWidget *xhtmlite_textview = xhtmlite_widget_find_child_by_name (box, "xhtmlite_textview");
						GtkTextBuffer *textbuffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(xhtmlite_textview));
						gchar *text = xhtmlite_write_as_markup(textbuffer);
						rc = xmlTextWriterWriteFormatRaw(writer, "%s", BAD_CAST text);
						if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterWriteString\n");return;}	
					}
				}
			}
		
			/* Close the element named 'td'. */
			printf("write end 'td' element\n");
			rc = xmlTextWriterEndElement(writer);
			if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterEndElement\n"); return;}
				
		}
		
		/* Close the element named 'tr'. */
			rc = xmlTextWriterWriteString(writer, BAD_CAST "\n");
		printf("write end 'tr' element\n");
		rc = xmlTextWriterEndElement(writer);
		if (rc < 0) {printf("testXmlwriterFilename: Error at xmlTextWriterEndElement\n"); return;}
		
	}
	

	
	/* Close all the remaining elements */
		rc = xmlTextWriterWriteString(writer, BAD_CAST "\n");
	printf("write end document\n");
	rc = xmlTextWriterEndDocument(writer);
	if (rc < 0) {
		printf("XmlwriterFilename: Error at xmlTextWriterEndDocument\n");
		return;
	}

	xmlFreeTextWriter(writer);

	//return filename or file
}
